/*
 * IndicatorForm JS - interactivity for indicator form
 *
 */
let IndicatorForm = {
  goalValueInputGroup: null,
  unitsInputGroup: null,

  init(indicatorSelect) {
    let indicatorUnitsInput = document.getElementById("indicator_units_es");

    IndicatorForm.goalValueInputGroup = document.getElementById("indicator_goal_value").parentElement.parentElement;
    IndicatorForm.unitsInputGroup = indicatorUnitsInput.parentElement.parentElement.parentElement;

    // Set available inputs for the current selected option
    let selectedOption = indicatorSelect.selectedOptions[0];
    IndicatorForm.setGoalInputVisibility(selectedOption);
    IndicatorForm.setUnitsInputVisibility(selectedOption);
    IndicatorForm.setGoalValueAppendText(indicatorUnitsInput.value);

    // Add event listener on select change
    indicatorSelect.addEventListener("change", IndicatorForm.kindChangedCallback);

    // Add event listener on units input change
    indicatorUnitsInput.addEventListener("change", IndicatorForm.unitsInputChangedCallback);
  },

  kindChangedCallback(event) {
    let selectedOption = event.target.selectedOptions[0];
    IndicatorForm.setGoalInputVisibility(selectedOption);
    IndicatorForm.setUnitsInputVisibility(selectedOption);
  },

  unitsInputChangedCallback(event) {
    let val = event.target.value;

    IndicatorForm.setGoalValueAppendText(val);
  },

  setGoalInputVisibility(selectedOption) {
    if (selectedOption.dataset.hasGoalValue == "true") {
      IndicatorForm.goalValueInputGroup.classList.remove("hidden");
    } else {
      IndicatorForm.goalValueInputGroup.classList.add("hidden");
    }
  },

  setUnitsInputVisibility(selectedOption) {
    if (selectedOption.dataset.hasIndicatorUnits == "true") {
      IndicatorForm.unitsInputGroup.classList.remove("hidden");
    } else {
      IndicatorForm.unitsInputGroup.classList.add("hidden");
    }
  },

  setGoalValueAppendText(val) {
    let inputAppend = document.getElementById("units-value-append");

    if (val !== "") {
      inputAppend.innerHTML = val;
      inputAppend.classList.add("btn-outline-secondary");
    } else {
      inputAppend.innerHTML = "";
      inputAppend.classList.remove("btn-outline-secondary");
    }
  }
}

export default IndicatorForm;
