/*
 * Sortable list implementation using HTML5 draggable attribute
 * https://developer.mozilla.org/en-US/docs/Web/API/HTML_Drag_and_Drop_API/Drag_operations
 * https://codepen.io/crouchingtigerhiddenadam/pen/qKXgap
 * */

let SortableList = {
  selected: null,
  orderInput: null,

  init() {
    Array.from(document.getElementsByClassName("draggable-item")).forEach(function(draggable) {
      draggable.addEventListener("dragend", function(event) {
        SortableList.dragEnd();
      });

      draggable.addEventListener("dragover", function(event) {
        SortableList.dragOver(event);
      });

      draggable.addEventListener("dragstart", function(event) {
        SortableList.dragStart(event);
      });
    });

    SortableList.orderInput = document.getElementById("current_order");
  },

  dragOver( e ) {
    if ( SortableList.isBefore( SortableList.selected, e.target ) ) {
      e.target.parentNode.insertBefore( SortableList.selected, e.target )
    } else {
      e.target.parentNode.insertBefore( SortableList.selected, e.target.nextSibling )
    }
  },

  dragEnd() {
    let currentList = Array.from(SortableList.selected.parentNode.getElementsByClassName("draggable-item")).reduce(function(acc, current) {
      acc.push(current.dataset.itemId);
      return acc;
    }, []);
    SortableList.orderInput.value = currentList;

    SortableList.selected.classList.remove("dragged");
    SortableList.selected = null
  },

  dragStart( e ) {
    e.dataTransfer.effectAllowed = "move";
    e.dataTransfer.setData( "text/plain", null );
    SortableList.selected = e.target;
    SortableList.selected.classList.add("dragged");

    return SortableList.selected;
  },

  isBefore( el1, el2 ) {
    var cur;

    if ( el2.parentNode === el1.parentNode ) {
      for ( cur = el1.previousSibling; cur; cur = cur.previousSibling ) {
        if (cur === el2) return true
      }
    } else {
      return false;
    }
  }
}

export default SortableList;
