use Mix.Config

# For development, we disable any cache and enable
# debugging and code reloading.
#
# The watchers configuration can be used to run external
# watchers to your application. For example, we use it
# with webpack to recompile .js and .css sources.
#
# See https://github.com/phoenixframework/phoenix/blob/master/lib/phoenix/endpoint.ex
# for all options
config :ogp_euskadi, OgpEuskadiWeb.Endpoint,
  http: [port: 4000],
  debug_errors: false,
  code_reloader: true,
  check_origin: false,
  watchers: [
    node: [
      "node_modules/webpack/bin/webpack.js",
      "--mode",
      "development",
      "--watch-stdin",
      cd: Path.expand("../assets", __DIR__)
    ]
  ]

# ## SSL Support
#
# In order to use HTTPS in development, a self-signed
# certificate can be generated by running the following
# Mix task:
#
#     mix phx.gen.cert
#
# Note that this task requires Erlang/OTP 20 or later.
# Run `mix help phx.gen.cert` for more information.
#
# The `http:` config above can be replaced with:
#
#     https: [
#       port: 4001,
#       cipher_suite: :strong,
#       keyfile: "priv/cert/selfsigned_key.pem",
#       certfile: "priv/cert/selfsigned.pem"
#     ],
#
# If desired, both `http:` and `https:` keys can be
# configured to run both http and https servers on
# different ports.

# Watch static and templates for browser reloading.
config :ogp_euskadi, OgpEuskadiWeb.Endpoint,
  live_reload: [
    patterns: [
      ~r{priv/static/.*(js|css|png|jpeg|jpg|gif|svg)$},
      ~r{priv/gettext/.*(po)$},
      ~r{lib/ogp_euskadi_web/views/.*(ex)$},
      ~r{lib/ogp_euskadi_web/templates/.*(eex)$},
      ~r{lib/ogp_euskadi_web/live/.*(ex)$}
    ]
  ]

# Do not include metadata nor timestamps in development logs
config :logger, :console, format: "[$level] $message\n"

# Set a higher stacktrace during development. Avoid configuring such
# in production as building large stacktraces may be expensive.
config :phoenix, :stacktrace_depth, 20

# Initialize plugs at runtime for faster development compilation
config :phoenix, :plug_init_mode, :runtime

# Bamboo mailer configuration: for development we use LocalAdapter
# The local adapter stores emails in memory that can be viewed during development.
# https://hexdocs.pm/bamboo/readme.html
config :ogp_euskadi, OgpEuskadiWeb.Mailer,
  adapter: Bamboo.LocalAdapter

# Configure your database
config :ogp_euskadi, OgpEuskadi.Repo,
  username: System.get_env("OGPE_DB_USERNAME"),
  password: System.get_env("OGPE_DB_PASSWD"),
  database: "open_ogpe_dev",
  hostname: "localhost",
  pool_size: 10
