use Mix.Config

# For production, don't forget to configure the url host
# to something meaningful, Phoenix uses this information
# when generating URLs.
#
# Note we also include the path to a cache manifest
# containing the digested version of static files. This
# manifest is generated by the `mix phx.digest` task,
# which you should run after static files are built and
# before starting your production server.
config :ogp_euskadi, OgpEuskadiWeb.Endpoint,
  http: [:inet6, port: System.get_env("PORT") || 4030],
  url: [host: System.get_env("OGPE_HOST"), port: 80],
  secret_key_base: "7aL51N+pghKdfg+mM3JrUO8uKNcPMgDD+95gXvuK7lNdfh8s7g6hU8Rk978+fK7x",
  cache_static_manifest: "priv/static/cache_manifest.json"

# Do not print debug messages in production
config :logger, level: :info

# Configures Elixir's Logger
config :logger, :log_1,
  path: "/data/app/ogpe-logs/info.log",
  level: :info,
  format: "$date $time $metadata[$level] $message\n",
  metadata: [:request_id]


# ## SSL Support
#
# To get SSL working, you will need to add the `https` key
# to the previous section and set your `:url` port to 443:
#
#     config :ogp_euskadi, OgpEuskadiWeb.Endpoint,
#       ...
#       url: [host: "example.com", port: 443],
#       https: [
#         :inet6,
#         port: 443,
#         cipher_suite: :strong,
#         keyfile: System.get_env("SOME_APP_SSL_KEY_PATH"),
#         certfile: System.get_env("SOME_APP_SSL_CERT_PATH")
#       ]
#
# The `cipher_suite` is set to `:strong` to support only the
# latest and more secure SSL ciphers. This means old browsers
# and clients may not be supported. You can set it to
# `:compatible` for wider support.
#
# `:keyfile` and `:certfile` expect an absolute path to the key
# and cert in disk or a relative path inside priv, for example
# "priv/ssl/server.key". For all supported SSL configuration
# options, see https://hexdocs.pm/plug/Plug.SSL.html#configure/1
#
# We also recommend setting `force_ssl` in your endpoint, ensuring
# no data is ever sent via http, always redirecting to https:
#
#     config :ogp_euskadi, OgpEuskadiWeb.Endpoint,
#       force_ssl: [hsts: true]
#
# Check `Plug.SSL` for all available options in `force_ssl`.

# ## Using releases (distillery)
#
# If you are doing OTP releases, you need to instruct Phoenix
# to start the server for all endpoints:
#
#     config :phoenix, :serve_endpoints, true
#
# Alternatively, you can configure exactly which server to
# start per endpoint:
#
#     config :ogp_euskadi, OgpEuskadiWeb.Endpoint, server: true
#
# Note you can't rely on `System.get_env/1` when using releases.
# See the releases documentation accordingly.

# Finally import the config/prod.secret.exs which should be versioned
# separately.
# import_config "prod.secret.exs"


# Bamboo Mailer config
config :ogp_euskadi, OgpEuskadiWeb.Mailer,
  adapter: Bamboo.SMTPAdapter,
  server: "localhost",
  hostname: System.get_env("OGPE_HOST"),
  port: 25

# Database config
config :ogp_euskadi, OgpEuskadi.Repo,
  username: System.get_env("OGPE_DB_USERNAME"),
  port: System.get_env("OGPE_DB_PORT"),
  password: System.get_env("OGPE_DB_PASSWD"),
  database: "open_ogpe_prod",
  hostname: "localhost",
  show_sensitive_data_on_connection_error: false,
  pool_size: 10
