defmodule OgpEuskadi.Auth do

  import Ecto.Query, warn: false
  alias OgpEuskadi.Repo

  alias OgpEuskadi.Site.Entity
  alias OgpEuskadi.Auth.ApiKey
  alias OgpEuskadi.Auth.Guardian

  def generate_entity_api_key(%Entity{} = entity) do
    key = 10
      |> :crypto.strong_rand_bytes()
      |> Base.encode16()

    entity = preload_api_key(entity)
    case entity.api_key do
      nil ->
        %ApiKey{entity_id: entity.id, client: entity.tenant}
      api_key ->
        api_key
    end
    |> ApiKey.changeset(%{key: key})
    |> Repo.insert_or_update()
  end

  def preload_api_key(entity) do
    Repo.preload(entity, :api_key)
  end

  def get_resource_by_id(id) do
    case ApiKey |> Repo.get(id) do
      %ApiKey{} = api_key ->
        api_key = api_key |> Repo.preload(:entity)
        api_key.entity

      _ -> nil
    end
  end

  def get_client_by_api_key!(client, api_key) do
    (from a in ApiKey, where: a.client == ^client and a.key == ^api_key)
    |> Repo.one!
  end

  @doc """
  Autheticate a client by api_key.
  If the client exists, {:ok, guardian_token, guardian_subject} is returned.
  guardian_subject contains the ApiKey id.
  If no client with the provided api_key exists raises Ecto.NoResultsError
  """
  def authenticate_client_by_api_key!(client, api_key) do
    get_client_by_api_key!(client, api_key)
    |> Guardian.encode_and_sign()
  end
end
