defmodule OgpEuskadi.Basic.IndicatorKind do
  use Ecto.Schema
  use OgpEuskadi.Translator, translates: [:name, :options]

  import Ecto.Changeset

  @types [:phases, :precentage, :numeric]

  schema "indicator_kinds" do
    field :name_es, :string
    field :name_eu, :string
    field :options_es, :string
    field :options_eu, :string
    field :type, :string
    field :position, :integer

    field :name, :string, virtual: true
    field :options, :string, virtual: true

    timestamps()
  end

  @doc false
  def changeset(indicator_kind, attrs) do
    # 2DO - options_es es obligatorio si type == "phases"
    indicator_kind
    |> cast(attrs, [:type, :name_es, :name_eu, :options_es, :options_eu, :position])
    |> validate_required([:type, :name_es])
  end

  def options_list(indicator_kind, "eu") do
    if is_binary(indicator_kind.options_eu) do
      indicator_kind.options_eu |> String.split("|")
    else
      []
    end
  end

  def options_list(indicator_kind, _locale) do
    if is_binary(indicator_kind.options_es) do
      indicator_kind.options_es |> String.split("|")
    else
      []
    end
  end

  def options_data(indicator_kind) do
    options_es = options_list(indicator_kind, "es")
    options_eu = options_list(indicator_kind, "eu")

    if length(options_es) > 0 do
      (0..(length(options_es)-1)) |> Enum.map(fn i ->
        %{
          name_es: Enum.at(options_es, i),
          name_eu: Enum.at(options_eu, i),
          value: i
        }
      end)
    else
      []
    end
  end
end
