defmodule OgpEuskadi.Config.Subdivision do
  use Ecto.Schema
  use OgpEuskadi.Translator, translates: [:name, :description]

  import Ecto.Changeset

  alias OgpEuskadi.Plan

  schema "subdivisions" do
    field :description_es, :string
    field :description_eu, :string
    field :name_es, :string
    field :name_eu, :string

    field :description, :string, virtual: true
    field :name, :string, virtual: true

    has_many :act_subdivisions, Plan.ActSubdivision, on_delete: :delete_all, on_replace: :delete
    has_many :acts, through: [:act_subdivisions, :act]
    has_many :activities, through: [:acts, :activities]


    timestamps()
  end

  @doc false
  def changeset(subdivision, attrs) do
    subdivision
    |> cast(attrs, [:name_es, :name_eu, :description_es, :description_eu])
    |> validate_required([:name_es, :description_es])
  end
end
