defmodule OgpEuskadi.Monitoring.ActMonitoring do
  use Ecto.Schema

  import Ecto.Changeset

  schema "acts" do
    field :last_activity_date, :date
    field :inserted_at, :utc_datetime
  end

  # If there is no value for last_activity_date, the current value is kept.
  def changeset(act, attrs) do
    attrs = cond do
      is_nil(attrs["last_activity_date"]) ->
        attrs |> Map.replace("last_activity_date", DateTime.to_date(act.inserted_at))
      is_binary(attrs["last_activity_date"]) ->
        [d,m,y] =
          attrs["last_activity_date"]
          |> String.split("/")

        case  Date.from_iso8601("#{y}-#{m}-#{d}") do
          {:ok, date} ->
            attrs |> Map.replace("last_activity_date", date)

          {:error, _reason} ->
            attrs |> Map.replace("last_activity_date", act.last_activity_date)
        end

      true ->
        attrs
    end

    act
    |> cast(attrs, [:last_activity_date])
  end
end
