defmodule OgpEuskadi.Monitoring.Activity do
  use Ecto.Schema
  use OgpEuskadi.Translator, translates: [:title, :description], translates_assoc: [:act, :photos, :documents, :activity_indicators]

  import Ecto.Changeset

  import OgpEuskadi.DateInput

  alias OgpEuskadi.Plan
  alias OgpEuskadi.Archive
  alias OgpEuskadi.Monitoring

  schema "activities" do
    field :date, OgpEuskadi.TextDate
    field :description_es, :string
    field :description_eu, :string
    field :title_es, :string
    field :title_eu, :string
    field :draft, :boolean

    field :description, :string, virtual: true
    field :title, :string, virtual: true

    field :discards_act, :boolean

    belongs_to :act, Plan.Act

    has_many :photos, Archive.Photo
    has_many :documents, Archive.Document

    has_many :activity_indicators, Monitoring.ActivityIndicator, on_replace: :delete #, on_delete: :delete_all - no funciona con los prfixes????

    timestamps()
  end

  @doc false
  def changeset(activity, attrs) do
    # 2DO - check activity indicators values. If empty and new record, set current indicator value
    activity
    |> cast(attrs, [:title_es, :title_eu, :description_es, :description_eu, :date, :act_id, :draft, :discards_act])
    |> Ecto.Changeset.cast_assoc(:activity_indicators, required: true)
    |> validate_required([:title_es, :description_es, :date, :act_id, :activity_indicators])
    |> validate_length(:title_es, max: 255)
    |> validate_length(:title_eu, max: 255)
    |> foreign_key_constraint(:act_id)
  end

  def format_text_dates_for_html(changeset) do
    changeset
    |> put_change(:date, date_input_format(get_field(changeset, :date)))
  end

end
