defmodule OgpEuskadi.Monitoring.Indicator do
  use Ecto.Schema
  use OgpEuskadi.Translator, translates: [:title, :units], translates_assoc: [:indicator_kind]

  import Ecto.Query
  import Ecto.Changeset

  alias OgpEuskadi.Basic
  alias OgpEuskadi.Plan
  alias OgpEuskadi.Monitoring

  alias OgpEuskadi.Repo

  schema "indicators" do
    field :current_value, :decimal
    field :goal_value, :decimal
    field :title_es, :string
    field :title_eu, :string
    field :units_es, :string
    field :units_eu, :string

    field :title, :string, virtual: true
    field :units, :string, virtual: true

    field :current_value_es, :decimal, virtual: true
    field :current_value_eu, :decimal, virtual: true

    has_many :activity_indicators, Monitoring.ActivityIndicator #, on_delete: :delete_all ??? does notwork with triplex because do not use the prefix????

    belongs_to :act, Plan.Act
    belongs_to :indicator_kind, Basic.IndicatorKind, foreign_key: :kind_id

    timestamps()
  end

  @doc false
  def changeset(indicator, attrs) do
    indicator
    |> cast(attrs, [:kind_id, :act_id, :title_es, :title_eu, :goal_value, :units_es, :units_eu, :current_value])
    |> validate_required([:act_id, :title_es, :kind_id])
    |> validate_length(:title_es, max: 255)
    |> validate_length(:title_eu, max: 255)
    |> validate_length(:units_es, max: 30)
    |> validate_length(:units_eu, max: 30)
    |> foreign_key_constraint(:act_id, name: "indicators_act_id_fkey")
    |> foreign_key_constraint(:kind_id, name: "indicators_kind_id_fkey")
    |> validate_change(:current_value, fn :current_value, val ->
         [current_value: "can not be updated directly. Please, use activities to update indicator values"]
       end)
    |> validate_change(:kind_id, fn :kind_id, kind_id ->
       if !!indicator.id do
         q = from Monitoring.ActivityIndicator, where: [indicator_id: ^indicator.id]
         if Repo.aggregate(q, :count, prefix: Ecto.get_meta(indicator, :prefix)) > 0 do
           [kind_id: "can not be changed for indicator with activities"]
         else
           []
         end
       else
         []
       end
      end)
  end

end
