# Based on https://blog.drewolson.org/pagination-with-phoenix-ecto
defmodule OgpEuskadi.Paginator do
  defstruct [:entries, :page, :last, :page_size]

  import Ecto.Query

  alias OgpEuskadi.Repo

  def new(query, params, prefix) do
    page_number = Map.get(params, :page_number, 1)
    page_size = Map.get(params, :page_size, 10)

    %OgpEuskadi.Paginator{
      entries: entries(query, page_number, page_size, prefix),
      page: page_number,
      page_size: page_size,
      last: total_pages(query, page_size, prefix)
    }
  end

  defp ceiling(float) do
    t = trunc(float)

    case float - t do
      neg when neg < 0 ->
        t
      pos when pos > 0 ->
        t + 1
      _ -> t
    end
  end

  defp entries(query, page_number, page_size, prefix) do
    offset = page_size * (page_number - 1)

    query
    |> limit(^page_size)
    |> offset(^offset)
    |> Repo.all(prefix: prefix)
  end

  defp total_pages(query, page_size, prefix) do
    count =
      query
      |> exclude(:order_by)
      |> exclude(:preload)
      |> exclude(:select)
      |> select([e], count(e.id))
      |> Repo.one(prefix: prefix)

    ceiling(count / page_size)
  end

end
