defmodule OgpEuskadi.Search do
  import Ecto.Query, warn: false
  import OgpEuskadi.QueryableTools

  alias OgpEuskadi.Repo

  alias OgpEuskadi.Translator

  alias OgpEuskadi.Plan.Goal
  alias OgpEuskadi.Plan.Act
  alias OgpEuskadi.Monitoring.Activity

  alias OgpEuskadi.Search.MatchingItem

  def list_items(search_term, locale, prefix) do
    search_items(search_term, prefix)
    |> Translator.translate(locale)
  end

  def search_items(search_term, prefix) do
    g_query = goals_query(search_term, prefix)

    act_query = acts_query(search_term, prefix)
    activities_query = activities_query(search_term, prefix)
    a_query = from a in act_query, union_all: ^activities_query

    (from g in g_query, union_all: ^a_query, order_by: [desc: fragment("rank")])
    |> Repo.all(prefix: prefix)
  end

  def goals_query(search_term, prefix) do
    queriable = Goal

    query = from item in queriable,
      join: m_items in subquery(matching_items(queriable, search_term), prefix: prefix),
      on: m_items.id == item.id,
      select: %MatchingItem{id: item.id, title_es: item.title_es, title_eu: item.title_eu, rank: m_items.rank, kind: fragment("'goal' AS kind"), act_id: fragment("NULL AS act_id")}
  end

  def acts_query(search_term, prefix) do
    queriable = Act

    query =
      from item in queriable,
      join: m_items in subquery(matching_items(queriable, search_term), prefix: prefix),
      on: m_items.id == item.id,
      select: %MatchingItem{id: item.id, title_es: item.title_es, title_eu: item.title_eu, rank: m_items.rank, kind: fragment("'act' AS kind"), act_id: item.id}
  end

  def activities_query(search_term, prefix) do
    queriable = Activity

    query =
      from item in queriable,
      join: m_items in subquery(matching_items(queriable, search_term), prefix: prefix),
      on: m_items.id == item.id,
      select: %MatchingItem{id: item.id, title_es: item.title_es, title_eu: item.title_eu, rank: m_items.rank, kind: fragment("'activity' AS kind"), act_id: item.act_id}
  end

  def matching_items(query, search_term) do
    from g in query,
      select: %{id: g.id, rank: fragment("ts_rank(to_tsvector('es', title_es || coalesce(title_eu, '')), plainto_tsquery('es', ?))", ^search_term)},
      where: fragment("to_tsvector('es', (title_es || coalesce(description_es, ''))) @@ plainto_tsquery('es', ?)", ^search_term),
      or_where: fragment("to_tsvector('es', (coalesce(title_eu, '') || coalesce(description_eu, ''))) @@ plainto_tsquery('es', ?)", ^search_term)
  end

end
