# References:
# http://learningelixir.joekain.com/custom-types-in-ecto/
# https://elixirforum.com/t/date-formats-phoenix-and-ecto/5220
defmodule OgpEuskadi.TextDate do
  @behaviour Ecto.Type

  # Type to store the value at DB level
  def type(), do: :date

  # Takes Elixir value and converts it into a value that the database recognizes
  def dump(term) do
    Ecto.Type.dump(:date, term)
  end

  # Takes DB value and converts it into Elixir value
  def load(term) do
    {:ok, date} = Ecto.Type.load(:date, term)
    {:ok, ([date.day, date.month] |> Enum.map(fn n -> Integer.to_string(n) |> String.pad_leading(2, "0") end) |> Enum.join("/"))<>"/#{date.year}"}
  end

  # Takes external input and converts is into a format that Ecto can work with
  def cast(%Date{} = date), do: {:ok, date}

  def cast(%DateTime{} = datetime), do: {:ok, datetime}

  def cast(text_date) do
    cond do
      String.match?(text_date, ~r/\d{4}-\d{2}-\d{2}/) ->
        [y,m,d] = String.split(text_date, "-") |> Enum.map(fn n -> String.to_integer(n) end)
        case Date.new(y,m,d) do
          {:ok, date} -> {:ok, date}
          _ -> :error
        end
      String.match?(text_date, ~r/\d{2}\/\d{2}\/\d{4}/) ->
        [d,m,y] = String.split(text_date, "/") |> Enum.map(fn n -> String.to_integer(n) end)
        case Date.new(y,m,d) do
          {:ok, date} -> {:ok, date}
          _ -> :error
        end
      true ->
        :error
    end
  end

  def get_text_date(date) do
    [date.day, date.month]
    |> Enum.map(fn n ->
      Integer.to_string(n)
      |> String.pad_leading(2, "0")
    end)
    |> Enum.concat(["#{date.year}"])
    |> Enum.join("/")
  end

end
