defmodule OgpEuskadiWeb.Admin.ActController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Translator
  alias OgpEuskadi.Basic
  alias OgpEuskadi.Config
  alias OgpEuskadi.Plan
  alias OgpEuskadi.Plan.Act

  def index(conn, _params, prefix) do
    acts = Plan.list_acts_with_activities_counter(prefix) |> Translator.translate(conn.assigns.locale)
    render(conn, "index.html", acts: acts)
  end

  def sort(conn, %{"goal_id" => goal_id}, prefix) do
    goal = Plan.get_goal!(goal_id, prefix) |> Translator.translate(conn.assigns.locale)
    acts =
      goal
      |> Plan.list_goal_acts()
      |> Translator.translate(conn.assigns.locale)
    render(conn, "sort.html", acts: acts, goal: goal)
  end

  def save_order(conn, %{"goal_id" => goal_id, "current_order" => ordered_ids}, prefix) do
    goal = Plan.get_goal!(goal_id, prefix)
    case Plan.reorder_acts(String.split(ordered_ids, ","), prefix) do
      {:ok, _result} ->
        conn
        |> put_flash(:info, gettext("¡Acciones ordenadas!"))
        |> redirect(to: Routes.admin_goal_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, goal))

      {:error, _value} ->
        goal = Plan.get_goal!(goal_id, prefix) |> Translator.translate(conn.assigns.locale)
        acts = goal |> Plan.list_goal_acts() |> Translator.translate(conn.assigns.locale)
        render(conn, "sort.html", acts: acts, goal: goal)
    end

  end


  def new(conn, params, prefix) do
    goal_id = params["goal_id"]
    locale = conn.assigns.locale
    # goals = Plan.list_goals(prefix) |> Translator.translate(conn.assigns.locale)
    # subdivisions = Config.list_subdivisions(prefix) |> Translator.translate(conn.assigns.locale)
    # ods = Basic.list_ods(prefix) |> Translator.translate(conn.assigns.locale)
    changeset = Plan.change_act(%Act{}, %{"goal_id" => goal_id, "prefix" => prefix})
    render(conn, "new.html", changeset: changeset, goals: get_goals(prefix, locale), topics: get_sorted_topics(prefix, locale), subdivisions: get_subdivisions(prefix, locale), ods: get_ods(prefix, locale))
  end

  def create(conn, %{"act" => act_params}, prefix) do
    case Plan.create_act(act_params, prefix) do
      {:ok, act} ->
        add_next_link =
          Phoenix.HTML.Link.link(gettext("Crear otra acción dentro del mismo Objetivo."),
            to: Routes.admin_act_path(conn, :new, conn.assigns.tenant, conn.assigns.locale, goal_id: act.goal_id),
            class: "ef-admin-inline-btn-link")
        conn
        |> put_flash(:info, Phoenix.HTML.raw(gettext("¡Acción creada!")<>Phoenix.HTML.safe_to_string(add_next_link)))
        |> redirect(to: Routes.admin_act_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, act))

      {:error, %Ecto.Changeset{} = changeset} ->
        locale = conn.assigns.locale
        # goals = Plan.list_goals(prefix) |> Translator.translate(conn.assigns.locale)
        # topics = Basic.list_topics(prefix) |> Translator.translate(conn.assigns.locale)
        # subdivisions = Config.list_subdivisions(prefix) |> Translator.translate(conn.assigns.locale)
        # ods = Basic.list_ods(prefix) |> Translator.translate(conn.assigns.locale)
        changeset = changeset |> Act.format_text_dates_for_html |> Act.fill_form_data()
        render(conn, "new.html", changeset: changeset, goals: get_goals(prefix, locale), topics: get_sorted_topics(prefix, locale), subdivisions: get_subdivisions(prefix, locale), ods: get_ods(prefix, locale))
    end
  end

  def show(conn, %{"id" => id}, prefix) do
    act = Plan.get_act_with_activities!(id, prefix) |> Translator.translate(conn.assigns.locale)
    render(conn, "show.html", act: act)
  end

  def edit(conn, %{"id" => id}, prefix) do
    locale = conn.assigns.locale
    act = Plan.get_act!(id, prefix) |> Translator.translate(conn.assigns.locale)
    # goals = Plan.list_goals(prefix) |> Translator.translate(conn.assigns.locale)
    # topics = Basic.list_topics(prefix) |> Translator.translate(conn.assigns.locale)
    # subdivisions = Config.list_subdivisions(prefix) |> Translator.translate(conn.assigns.locale)
    # ods = Basic.list_ods(prefix) |> Translator.translate(conn.assigns.locale)

    changeset = Plan.change_act(act) |> Act.format_text_dates_for_html
    render(conn, "edit.html", act: act, goals: get_goals(prefix, locale), changeset: changeset, topics: get_sorted_topics(prefix, locale), subdivisions: get_subdivisions(prefix, locale), ods: get_ods(prefix, locale))
  end

  def update(conn, %{"id" => id, "act" => act_params}, prefix) do
    act = Plan.get_act!(id, prefix)

    # If no topic_ids is checked, topics_ids is not passed as attribute
    # Here we set it to empty string to indicate that no topis has been selected.
    # Same for subdivisions_ids and ods_ids
    act_params = Map.merge(%{"topics_ids" => [], "subdivisions_ids" => [], "ods_ids" => []}, act_params)

    case Plan.update_act(act, act_params) do
      {:ok, act} ->
        conn
        |> put_flash(:info, gettext("¡Acción actualizada!"))
        |> redirect(to: Routes.admin_act_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, act))

      {:error, %Ecto.Changeset{} = changeset} ->
        locale = conn.assigns.locale
        #goals = Plan.list_goals(prefix) |> Translator.translate(conn.assigns.locale)
        # topics = Basic.list_topics(prefix)|> Translator.translate(conn.assigns.locale)
        # subdivisions = Config.list_subdivisions(prefix) |> Translator.translate(conn.assigns.locale)
        # ods = Basic.list_ods(prefix) |> Translator.translate(conn.assigns.locale)
        changeset = changeset |> Act.format_text_dates_for_html() |> Act.fill_form_data()
        render(conn, "edit.html", act: act, goals: get_goals(prefix, locale), changeset: changeset, topics: get_sorted_topics(prefix, locale), subdivisions: get_subdivisions(prefix, locale), ods: get_ods(prefix, locale))
    end
  end

  def delete(conn, %{"id" => id}, prefix) do
    act = Plan.get_act!(id, prefix)

    case Plan.delete_act(act) do
      {:ok, _act} ->
        conn
        |> put_flash(:info, gettext("¡Acción eliminada!"))
        |> redirect(to: Routes.admin_act_path(conn, :index, conn.assigns.tenant, conn.assigns.locale))

      {:error, _changeset} ->
        conn
        |> put_flash(:error, gettext("Esta acción no se puede eliminar porque contiene actividades. Si quiere eliminar la acción, primero debe eliminar todas sus actividades."))
        |> redirect(to: Routes.admin_act_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, act))
    end
  end

  defp get_goals(prefix, locale) do
    Plan.list_goals(prefix) |> Translator.translate(locale)
  end

  defp get_subdivisions(prefix, locale) do
    Config.list_subdivisions(prefix) |> Translator.translate(locale) |> Enum.sort_by(&(&1.name))
  end

  defp get_sorted_topics(prefix, locale) do
    Basic.list_topics(prefix) |> Translator.translate(locale) |> Enum.sort_by(&(&1.title))
  end

  def get_ods(prefix, locale) do
    ods = Basic.list_ods(prefix) |> Translator.translate(locale)
  end
end
