defmodule OgpEuskadiWeb.Admin.ConfigController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Config
  alias OgpEuskadi.Translator

  def show(conn, _params, prefix) do
    entity_config = Config.get_entity_config(prefix) |> Translator.translate(conn.assigns.locale)
    subdivisions = Config.list_subdivisions(prefix) |> Translator.translate(conn.assigns.locale)
    entity_services = Config.list_entity_services(prefix) |> Translator.translate(conn.assigns.locale)
    render(conn, "show.html", entity_config: entity_config, subdivisions: subdivisions, entity_services: entity_services)
  end

  def edit(conn, _params, prefix) do
    entity_config = Config.get_entity_config(prefix)
    changeset = Config.change_entity_config(entity_config)
    render(conn, "edit.html", entity_config: entity_config, changeset: changeset)
  end

  def update(conn, %{"entity_config" => entity_config_params}, prefix) do
    entity_config = Config.get_entity_config(prefix)

    case Config.update_entity_config(entity_config, entity_config_params, prefix) do
      {:ok, entity_config} ->
        conn
        |> put_flash(:info, gettext("¡Configuración actualizada!"))
        |> redirect(to: Routes.admin_config_path(conn, :show, conn.assigns.tenant, conn.assigns.locale))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "edit.html", entity_config: entity_config, changeset: changeset)
    end
  end
end
