defmodule OgpEuskadiWeb.Admin.DocumentController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Monitoring
  alias OgpEuskadi.Archive
  alias OgpEuskadi.Archive.Document

  ### def index(conn, _params) do
  ###   documents = Archive.list_documents()
  ###   render(conn, "index.html", documents: documents)
  ### end

  def new(conn, %{"activity_id" => activity_id}, prefix) do
    activity = Monitoring.get_activity!(activity_id, prefix)
    changeset = Archive.change_document(%Document{activity_id: activity.id})
    render(conn, "new.html", changeset: changeset, activity: activity)
  end

  def create(conn, %{"document" => document_params}, prefix) do
    activity = Monitoring.get_activity!(document_params["activity_id"], prefix)
    case Archive.create_document(conn.assigns.current_user, document_params, prefix) do
      {:ok, document} ->
        conn
        |> put_flash(:info, gettext("¡Documento guardado!"))
        |> redirect(to: Routes.admin_activity_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, activity))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "new.html", changeset: changeset, activity: activity)
    end
  end

  ### def show(conn, %{"id" => id}) do
  ###   document = Archive.get_document!(id)
  ###   render(conn, "show.html", document: document)
  ### end

  def edit(conn, %{"id" => id}, prefix) do
    document = Archive.get_document!(id, prefix)
    changeset = Archive.change_document(document)
    render(conn, "edit.html", document: document, changeset: changeset, activity: document.activity)
  end

  def update(conn, %{"id" => id, "document" => document_params}, prefix) do
    document = Archive.get_document!(id, prefix)

    case Archive.update_document(conn.assigns.current_user, document, document_params) do
      {:ok, document} ->
        conn
        |> put_flash(:info, gettext("¡Documento actualizado!"))
        |> redirect(to: Routes.admin_activity_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, document.activity))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "edit.html", document: document, changeset: changeset, activity: document.activity)
    end
  end

  def delete(conn, %{"id" => id}, prefix) do
    document = Archive.get_document!(id, prefix)
    {:ok, _document} = Archive.delete_document(document)

    conn
    |> put_flash(:info, gettext("¡Documento eliminado!"))
    |> redirect(to: Routes.admin_activity_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, document.activity))
  end
end
