defmodule OgpEuskadiWeb.Admin.EntityServiceController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Config
  alias OgpEuskadi.Config.EntityService

  def new(conn, _params, prefix) do
    changeset = Config.change_entity_service(%EntityService{})
    render(conn, "new.html", changeset: changeset)
  end

  def create(conn, %{"entity_service" => entity_service_params}, prefix) do
    case Config.create_entity_service(entity_service_params, prefix) do
      {:ok, entity_service} ->
        conn
        |> put_flash(:info, gettext("¡Enlace a servicio creado!"))
        |> redirect(to: Routes.admin_config_path(conn, :show, conn.assigns.tenant, conn.assigns.locale))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "new.html", changeset: changeset)
    end
  end

  def edit(conn, %{"id" => id}, prefix) do
    entity_service = Config.get_entity_service!(id, prefix)
    changeset = Config.change_entity_service(entity_service)
    render(conn, "edit.html", entity_service: entity_service, changeset: changeset)
  end

  def update(conn, %{"id" => id, "entity_service" => entity_service_params}, prefix) do
    entity_service = Config.get_entity_service!(id, prefix)

    case Config.update_entity_service(entity_service, entity_service_params) do
      {:ok, entity_service} ->
        conn
        |> put_flash(:info, gettext("¡Enlace a servicio actualizado!"))
        |> redirect(to: Routes.admin_config_path(conn, :show, conn.assigns.tenant, conn.assigns.locale))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "edit.html", entity_service: entity_service, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}, prefix) do
    entity_service = Config.get_entity_service!(id, prefix)

    {:ok, _entity_service} = Config.delete_entity_service(entity_service)

    conn
    |> put_flash(:info, gettext("¡Enlace a servicio eliminado!"))
    |> redirect(to: Routes.admin_config_path(conn, :show, conn.assigns.tenant, conn.assigns.locale))
  end
end
