defmodule OgpEuskadiWeb.Admin.GoalController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Translator
  alias OgpEuskadi.Basic
  alias OgpEuskadi.Plan
  alias OgpEuskadi.Plan.Goal

  def index(conn, _params, prefix) do
    goals = Plan.list_goals_with_acts_counter(prefix) |> Translator.translate(conn.assigns.locale)
    render(conn, "index.html", goals: goals)
  end

  def sort(conn, _params, prefix) do
    goals = Plan.list_goals(prefix) |> Translator.translate(conn.assigns.locale)
    render(conn, "sort.html", goals: goals)
  end

  def save_order(conn, %{"current_order" => ordered_ids}, prefix) do
    new_ordered_ids = String.split(ordered_ids, ",") |> Enum.filter(fn(x) -> String.length(x) > 0 end)

    if length(new_ordered_ids) > 0 do
      case Plan.reorder_goals(new_ordered_ids, prefix) do
        {:ok, _result} ->
          conn
          |> put_flash(:info, gettext("¡Objetivos ordenados!"))
          |> redirect(to: Routes.admin_goal_path(conn, :index, conn.assigns.tenant, conn.assigns.locale))

        {:error, _value} ->
          goals = Plan.list_goals(prefix) |> Translator.translate(conn.assigns.locale)
          render(conn, "sort.html", goals: goals)
      end
    else
      conn
      |> put_flash(:info, gettext("El orden de los objetivos se mantiene."))
      |> redirect(to: Routes.admin_goal_path(conn, :index, conn.assigns.tenant, conn.assigns.locale))
    end

  end

  def new(conn, _params, prefix) do
    changeset = Plan.change_goal(%Goal{})
    render(conn, "new.html", changeset: changeset)
  end

  def create(conn, %{"goal" => goal_params}, prefix) do
    case Plan.create_goal(goal_params, prefix) do
      {:ok, goal} ->
        conn
        |> put_flash(:info, gettext("¡Objetivo creado!"))
        |> redirect(to: Routes.admin_goal_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, goal))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "new.html", changeset: changeset)
    end
  end

  def show(conn, %{"id" => id}, prefix) do
    goal = Plan.get_goal!(id, prefix)  |> Translator.translate(conn.assigns.locale)
    acts = Plan.get_goal_acts_with_activity_counters(goal) |> Translator.translate(conn.assigns.locale)
    render(conn, "show.html", goal: goal, acts: acts)
  end

  def edit(conn, %{"id" => id}, prefix) do
    goal = Plan.get_goal!(id, prefix)
    changeset = Plan.change_goal(goal)
    render(conn, "edit.html", goal: goal, changeset: changeset)
  end

  def update(conn, %{"id" => id, "goal" => goal_params}, prefix) do
    goal = Plan.get_goal!(id, prefix)

    case Plan.update_goal(goal, goal_params) do
      {:ok, goal} ->
        conn
        |> put_flash(:info, gettext("¡Objetivo actualizado!"))
        |> redirect(to: Routes.admin_goal_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, goal))

      {:error, %Ecto.Changeset{} = changeset} ->
        changeset = changeset |> Goal.fill_form_data()
        render(conn, "edit.html", goal: goal, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}, prefix) do
    goal = Plan.get_goal!(id, prefix)

    case Plan.delete_goal(goal) do
      {:ok, _goal} ->
        conn
        |> put_flash(:info, gettext("¡Objetivo eliminado!"))
        |> redirect(to: Routes.admin_goal_path(conn, :index, conn.assigns.tenant, conn.assigns.locale))

      {:error, _changeset} ->
        conn
        |> put_flash(:error, gettext("Este indicador no se puede eliminar porque contiene acciones. Si quiere eliminar el indicador, primero debe eliminar todas sus acciones."))
        |> redirect(to: Routes.admin_goal_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, goal))

    end
  end
end
