defmodule OgpEuskadiWeb.Admin.IndicatorController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Translator
  alias OgpEuskadi.Basic
  alias OgpEuskadi.Plan
  alias OgpEuskadi.Monitoring
  alias OgpEuskadi.Monitoring.Indicator

  def index(conn, %{"act_id" => act_id}, prefix) do
    act = Plan.get_act!(act_id, prefix) |> Translator.translate(conn.assigns.locale)
    indicators = act.indicators

    render(conn, "index.html", act: act, indicators: indicators)
  end

  def new(conn, %{"act_id" => act_id}, prefix) do
    act = Plan.get_act!(act_id, prefix) |> Translator.translate(conn.assigns.locale)
    indicator_kind_options = get_indicator_kinds_with_data_attributes(prefix, conn.assigns.locale)
    changeset = Monitoring.change_indicator(%Indicator{act_id: act_id})
    render(conn, "new.html", changeset: changeset, indicator_kind_options: indicator_kind_options, act: act)
  end

  def create(conn, %{"act_id" => act_id, "indicator" => indicator_params}, prefix) do
    case Monitoring.create_indicator(Map.put(indicator_params, "act_id", act_id), prefix) do
      {:ok, indicator} ->
        conn
        |> put_flash(:info, gettext("¡Indicador creado!"))
        |> redirect(to: Routes.admin_act_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, act_id))

      {:error, changeset} ->
        act = Plan.get_act!(act_id, prefix) |> Translator.translate(conn.assigns.locale)
        indicator_kind_options = get_indicator_kinds_with_data_attributes(prefix, conn.assigns.locale)
        render(conn, "new.html",  changeset: changeset, indicator_kind_options: indicator_kind_options, act: act)
    end
  end

  def edit(conn, %{"act_id" => act_id, "id" => id}, prefix) do
    act = Plan.get_act!(act_id, prefix) |> Translator.translate(conn.assigns.locale)
    indicator = Monitoring.get_indicator!(id, prefix)
    indicator_kind_options = get_indicator_kinds_with_data_attributes(prefix, conn.assigns.locale)

    changeset = Monitoring.change_indicator(indicator)

    render(conn, "edit.html", changeset: changeset, indicator_kind_options: indicator_kind_options, act: act, indicator: indicator)
  end

  def update(conn, %{"act_id" => act_id, "id" => id, "indicator" => indicator_params}, prefix) do
    indicator = Monitoring.get_indicator!(id, prefix)

    case Monitoring.update_indicator(indicator, indicator_params) do
      {:ok, indicator} ->
        conn
        |> put_flash(:info, gettext("¡Indicador actualizado!"))
        |> redirect(to: Routes.admin_act_indicator_path(conn, :index, conn.assigns.tenant, conn.assigns.locale, indicator.act_id))

      {:error, %Ecto.Changeset{} = changeset } ->
        act = Plan.get_act!(act_id, prefix) |> Translator.translate(conn.assigns.locale)
        indicator_kind_options = get_indicator_kinds_with_data_attributes(prefix, conn.assigns.locale)

        render(conn, "edit.html", changeset: changeset, indicator_kind_options: indicator_kind_options, act: act, indicator: indicator)
    end
  end

  def delete(conn, %{"act_id" => act_id, "id" => id}, prefix) do
    indicator = Monitoring.get_indicator!(id, prefix)
    {:ok, _indicator} = Monitoring.delete_indicator(indicator)

    conn
    |> put_flash(:info, gettext("¡Indicador eliminado!"))
    |> redirect(to: Routes.admin_act_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, indicator.act_id))
  end

  defp get_indicator_kinds_with_data_attributes(prefix, locale) do
    Basic.list_indicator_kinds(prefix)
    |> Translator.translate(locale)
    |> Enum.map(fn ik ->
      [
        key: ik.name,
        value: ik.id,
        "data-has-goal-value": (if ik.type == "numeric", do: "true"),
        "data-has-indicator-units": (if ik.type == "numeric", do: "true")
      ]
    end)
  end
end

