defmodule OgpEuskadiWeb.Admin.PhotoController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Monitoring
  alias OgpEuskadi.Archive
  alias OgpEuskadi.Archive.Photo

  ### def index(conn, %{"activity_id" => activity_id}) do
  ###   photos = Archive.list_photos()
  ###   render(conn, "index.html", photos: photos)
  ### end

  def new(conn, %{"activity_id" => activity_id}, prefix) do
    activity = Monitoring.get_activity!(activity_id, prefix)
    changeset = Archive.change_photo(%Photo{activity_id: activity.id})
    render(conn, "new.html", changeset: changeset, activity: activity)
  end

  def create(conn, %{"photo" => photo_params}, prefix) do
    activity = Monitoring.get_activity!(photo_params["activity_id"], prefix)
    case Archive.create_photo(conn.assigns.current_user, photo_params, prefix) do
      {:ok, photo} ->
        IO.puts " --------------- photo created, prefix #{photo.__meta__.prefix}"
        conn
        |> put_flash(:info, gettext("¡Foto guardada!"))
        |> redirect(to: Routes.admin_activity_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, activity))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "new.html", changeset: changeset, activity: activity)
    end
  end

  ### def show(conn, %{"id" => id}) do
  ###   photo = Archive.get_photo!(id)
  ###   render(conn, "show.html", photo: photo)
  ### end

  def edit(conn, %{"id" => id}, prefix) do
    photo = Archive.get_photo!(id, prefix)
    activity = photo.activity
    changeset = Archive.change_photo(photo)
    render(conn, "edit.html", photo: photo, changeset: changeset, activity: activity)
  end

  def update(conn, %{"id" => id, "photo" => photo_params}, prefix) do
    photo = Archive.get_photo!(id, prefix)

    case Archive.update_photo(conn.assigns.current_user, photo, photo_params) do
      {:ok, photo} ->
        conn
        |> put_flash(:info, "¡Foto actualizada!")
        |> redirect(to: Routes.admin_activity_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, photo.activity))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "edit.html", photo: photo, changeset: changeset, activity: photo.activity)
    end
  end

  def delete(conn, %{"id" => id}, prefix) do
    photo = Archive.get_photo!(id, prefix)

    {:ok, _photo} = Archive.delete_photo(photo)

    conn
    |> put_flash(:info, gettext("¡Foto eliminada!"))
    |> redirect(to: Routes.admin_activity_path(conn, :show, conn.assigns.tenant, conn.assigns.locale, photo.activity))
  end
end
