defmodule OgpEuskadiWeb.Admin.SubdivisionController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadi.Config
  alias OgpEuskadi.Config.Subdivision

  def new(conn, _params, prefix) do
    changeset = Config.change_subdivision(%Subdivision{})
    render(conn, "new.html", changeset: changeset)
  end

  def create(conn, %{"subdivision" => subdivision_params}, prefix) do
    case Config.create_subdivision(subdivision_params, prefix) do
      {:ok, subdivision} ->
        conn
        |> put_flash(:info, gettext("¡Ámbito geográfico creado!"))
        |> redirect(to: Routes.admin_config_path(conn, :show, conn.assigns.tenant, conn.assigns.locale))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "new.html", changeset: changeset)
    end
  end

  def edit(conn, %{"id" => id}, prefix) do
    subdivision = Config.get_subdivision!(id, prefix)
    changeset = Config.change_subdivision(subdivision)
    render(conn, "edit.html", subdivision: subdivision, changeset: changeset)
  end

  def update(conn, %{"id" => id, "subdivision" => subdivision_params}, prefix) do
    subdivision = Config.get_subdivision!(id, prefix)

    case Config.update_subdivision(subdivision, subdivision_params) do
      {:ok, subdivision} ->
        conn
        |> put_flash(:info, gettext("¡Ámbito geográfico actualizado!"))
        |> redirect(to: Routes.admin_config_path(conn, :show, conn.assigns.tenant, conn.assigns.locale))

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, "edit.html", subdivision: subdivision, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}, prefix) do
    subdivision = Config.get_subdivision!(id, prefix)

    {:ok, _subdivision} = Config.delete_subdivision(subdivision)

    conn
    |> put_flash(:info, gettext("¡Ámbito geográfico eliminado!"))
    |> redirect(to: Routes.admin_config_path(conn, :show, conn.assigns.tenant, conn.assigns.locale))

  end
end
