defmodule OgpEuskadiWeb.Api.ActController do
  use OgpEuskadiWeb, :controller

  action_fallback OgpEuskadiWeb.Api.FallbackController

  alias OgpEuskadiWeb.Exceptions.MissingParametersError
  alias OgpEuskadiWeb.Exceptions.ForbiddenActionError

  alias OgpEuskadi.Plan

  def index(conn, _params) do
    acts = Plan.list_acts(conn.assigns.prefix)
    render(conn, "index.json", acts: acts)
  end

  def show(conn, %{"id" => id}) do
    act = Plan.get_act!(id, conn.assigns.prefix)
    render(conn, "show.json", act: act)
  end

  def create(conn, %{"act" => act_params}) do
    with {:ok, act} <- Plan.create_act(act_params, conn.assigns.prefix) do
      conn
      |> put_status(:created)
      |> render("show.json", act: Plan.get_act!(act.id, conn.assigns.prefix))
    end
  end

  def create(conn, _params) do
    raise MissingParametersError, conn: conn, expected_parameters: ["act"]
  end

  def update(conn, %{"id" => id, "act" => act_params}) do
    act = Plan.get_act!(id, conn.assigns.prefix)

    # Set default values if no value is provided
    act_params = Map.merge(
      %{
        "topics_ids" => act.topics |> Enum.map(&(Integer.to_string(&1.id))),
        "subdivisions_ids" => act.subdivisions |> Enum.map(&(Integer.to_string(&1.id))),
        "ods_ids" => act.ods |> Enum.map(&(Integer.to_string(&1.id)))
      },
      act_params)

    with {:ok, act} <- Plan.update_act(act, act_params) do
      conn
      |> put_status(:ok)
      |> render("show.json", act: act)
    end
  end

  def update(conn, %{"id" => id}) do
    raise MissingParametersError, conn: conn, expected_parameters: ["act"]
  end

  def delete(conn, %{"id" => id}) do
    act = Plan.get_act!(id, conn.assigns.prefix)

    case Plan.delete_act(act) do
      {:ok, act} ->
        send_resp(conn, :no_content, "")

      {:error, %Ecto.Changeset{} = changeset} ->
        raise ForbiddenActionError, conn: conn, changeset: changeset
    end
  end

end
