defmodule OgpEuskadiWeb.Api.ActivityController do
  use OgpEuskadiWeb, :controller

  action_fallback OgpEuskadiWeb.Api.FallbackController

  alias OgpEuskadiWeb.Exceptions.MissingParametersError

  alias OgpEuskadi.Plan
  alias OgpEuskadi.Monitoring

  def index(conn, %{"act_id" => act_id}) do
    act = Plan.get_act_with_activities!(act_id, conn.assigns.prefix)
    render(conn, "index.json", activities: act.activities)
  end

  def show(conn, %{"id" => id}) do
    activity = Monitoring.get_activity!(id, conn.assigns.prefix)
    render(conn, "show.json", activity: activity)
  end

  def create(conn, %{"activity" => activity_params}) do
    with {:ok, %{activity: activity}} <- Monitoring.create_activity(activity_params, conn.assigns.prefix) do
      conn
      |> put_status(:created)
      |> render("show.json", activity: Monitoring.get_activity!(activity.id, conn.assigns.prefix))
    end
  end

  def create(conn, _params) do
    raise MissingParametersError, conn: conn, expected_parameters: ["activity"]
  end

  def update(conn, %{"id" => id, "activity" => activity_params}) do
    activity = Monitoring.get_activity!(id, conn.assigns.prefix)

    with {:ok, %{activity: activity}} <- Monitoring.update_activity(activity, activity_params) do
      conn
      |> put_status(:ok)
      |> render("show.json", activity: Monitoring.get_activity!(activity.id, conn.assigns.prefix))
    end
  end

  def update(conn, %{"id" => id}) do
    raise MissingParametersError, conn: conn, expected_parameters: ["activity"]
  end

  def delete(conn, %{"id" => id}) do
    activity = Monitoring.get_activity!(id, conn.assigns.prefix)
    {:ok, _activity} = Monitoring.delete_activity(activity)
    send_resp(conn, :no_content, "")
  end

end
