defmodule OgpEuskadiWeb.Api.GoalController do
  use OgpEuskadiWeb, :controller

  action_fallback OgpEuskadiWeb.Api.FallbackController

  alias OgpEuskadiWeb.Exceptions.MissingParametersError
  alias OgpEuskadiWeb.Exceptions.ForbiddenActionError

  alias OgpEuskadi.Plan

  def index(conn, _params) do
    goals = Plan.list_goals(conn.assigns.prefix)
    render(conn, "index.json", goals: goals)
  end

  def show(conn, %{"id" => id}) do
    goal = Plan.get_goal!(id, conn.assigns.prefix)
    render(conn, "show.json", goal: goal)
  end

  def create(conn, %{"goal" => goal_params}) do
    with {:ok, goal} <- Plan.create_goal(goal_params, conn.assigns.prefix) do
      conn
      |> put_status(:created)
      |> render("show.json", goal: goal)
    end
  end

  def create(conn, _params) do
    raise MissingParametersError, conn: conn, expected_parameters: ["goal"]
  end

  def update(conn, %{"id" => id, "goal" => goal_params}) do
    goal = Plan.get_goal!(id, conn.assigns.prefix)

    with {:ok, goal} <- Plan.update_goal(goal, goal_params) do
      conn
      |> put_status(:ok)
      |> render("show.json", goal: goal)
    end
  end

  def update(conn, %{"id" => id}) do
    raise MissingParametersError, conn: conn, expected_parameters: ["goal"]
  end

  def delete(conn, %{"id" => id}) do
    goal = Plan.get_goal!(id, conn.assigns.prefix)

    case Plan.delete_goal(goal) do
      {:ok, goal} ->
        send_resp(conn, :no_content, "")

      {:error, %Ecto.Changeset{} = changeset} ->
        raise ForbiddenActionError, conn: conn, changeset: changeset
    end
  end
end
