defmodule OgpEuskadiWeb.Api.IndicatorController do
  use OgpEuskadiWeb, :controller

  action_fallback OgpEuskadiWeb.Api.FallbackController

  alias OgpEuskadiWeb.Exceptions.MissingParametersError
  alias OgpEuskadiWeb.Exceptions.ForbiddenActionError

  alias OgpEuskadi.Monitoring
  alias OgpEuskadi.Plan

  def index(conn, %{"act_id" => act_id}) do
    indicators = Monitoring.list_act_indicators(act_id, conn.assigns.prefix)
    render(conn, "index.json", indicators: indicators)
  end

  def show(conn, %{"id" => id}) do
    indicator = Monitoring.get_indicator!(id, conn.assigns.prefix)
    render(conn, "show.json", indicator: indicator)
  end

  def create(conn, %{"indicator" => indicator_params}) do
    with {:ok, indicator} <- Monitoring.create_indicator(indicator_params, conn.assigns.prefix) do
      conn
      |> put_status(:created)
      |> render("show.json", indicator: Monitoring.get_indicator!(indicator.id, conn.assigns.prefix))
    end
  end

  def create(conn, _params) do
    raise MissingParametersError, conn: conn, expected_parameters: ["indicator"]
  end

  def update(conn, %{"id" => id, "indicator" => indicator_params}) do
    indicator = Monitoring.get_indicator!(id, conn.assigns.prefix)

    with {:ok, indicator} <- Monitoring.update_indicator(indicator, indicator_params) do
      conn
      |> put_status(:ok)
      |> render("show.json", indicator: Monitoring.get_indicator!(indicator.id, conn.assigns.prefix))
    end
  end

  def update(conn, %{"id" => id}) do
    raise MissingParametersError, conn: conn, expected_parameters: ["indicator"]
  end

  def delete(conn, %{"id" => id}) do
    indicator = Monitoring.get_indicator!(id, conn.assigns.prefix)

    case Monitoring.delete_indicator(indicator) do
      {:ok, _indicator} ->
        send_resp(conn, :no_content, "")

      {:error, %Ecto.Changeset{} = changeset} ->
        raise ForbiddenActionError, conn: conn, changeset: changeset

    end
  end
end
