defmodule OgpEuskadiWeb.Auth do
  import Plug.Conn
  import Phoenix.Controller

  alias OgpEuskadiWeb.Router.Helpers, as: Routes

  alias OgpEuskadi.Accounts
  alias OgpEuskadi.Site

  def init(opts), do: opts

  def call(conn, _opts) do
    prefix = Triplex.to_prefix(conn.assigns.tenant)
    [user_id: user_id_key] = get_session_keys(prefix)

    user_id = get_session(conn, user_id_key)

    cond do
      conn.assigns[:current_user] ->
        conn

      user = user_id && OgpEuskadi.Accounts.get_user(user_id, prefix) ->
        assign(conn, :current_user, user)

      true ->
        assign(conn, :current_user, nil)
    end
  end

  def login(conn, user) do
    prefix = Triplex.to_prefix(conn.assigns.tenant)
    [user_id: user_id_key] = get_session_keys(prefix)

    conn
    |> assign(:current_user, user)
    |> put_session(user_id_key, user.id)
    |> configure_session(renew: true)
  end

  def login_by_email_and_pass(conn, email, given_pass) do
    prefix = Triplex.to_prefix(conn.assigns.tenant)
    case Accounts.authenticate_by_email_and_pass(email, given_pass, prefix) do
      {:ok, user} -> {:ok, login(conn, user)}
      {:error, :unauthorized} -> {:error, :unauthorized, conn}
      {:error, :not_found} -> {:error, :not_found, conn}
    end
  end

  def logout(conn) do
    prefix = Triplex.to_prefix(conn.assigns.tenant)
    [user_id: user_id_key] = get_session_keys(prefix)

    # If you want ot delete all session data use configure_session(conn, drop: true)
    delete_session(conn, user_id_key) # Delete only user_id for the conn tenant
  end

  def authenticate_user(conn, params) do
    if conn.assigns[:current_user] do
      conn
    else
      conn
      |> put_flash(:error, "Tiene que identificarse para acceder a estas páginas.")
      |> redirect(to: Routes.session_path(conn, :new, conn.assigns.tenant, conn.assigns.locale))
      |> halt()
    end
  end

  defp get_session_keys(prefix) do
    [user_id: String.to_atom("#{prefix}_user_id")]
  end

end
