defmodule OgpEuskadiWeb.PasswordResetController do
  use OgpEuskadiWeb, :controller
  use OgpEuskadiWeb.CurrentPrefixHelper

  alias OgpEuskadiWeb.Mailer
  alias OgpEuskadiWeb.UserEmail

  alias OgpEuskadi.Accounts

  def new(conn, _params, prefix) do
    render(conn, "new.html")
  end

  def create(conn, %{"user" => %{"email" => email}}, prefix) do
    case Accounts.get_user_by_email(email, prefix) do
      %Accounts.User{} = user ->
        reset_url = Routes.password_reset_url(conn, :edit, conn.assigns.tenant, conn.assigns.locale, token: generate_token(conn, user))
        UserEmail.reset_token_email(user.username, user.credential.email, reset_url)
        |>  Mailer.deliver_now()
        conn
        |> put_flash(:info, gettext("¡Instrucciones enviadas a %{email}!", email: email))
        |> render("email_sent.html")

      _ ->
        conn
        |> render("email_sent.html")
    end
  end

  def edit(conn, %{"token" => token}, prefix) do
    case authenticate_by_token(conn, token, prefix) do
      {:ok, %Accounts.User{} = user} ->
        changeset = Accounts.change_credential(user.credential)

        conn
        |> render("edit.html", changeset: changeset, token: token)
      {:error, _} ->
        conn
        |> put_flash(:error, gettext("El enlace no es correcto o ha caducado. El tiempo de validez es de 2 horas."))
        |> render("new.html")
    end
  end


  def update(conn, %{"token" => token, "credential" => credential_params}, prefix) do
    case authenticate_by_token(conn, token, prefix) do
      {:ok, %Accounts.User{} = user} ->
        case Accounts.update_credential(user.credential, credential_params) do
          {:ok, _credential} ->
            conn
            |> put_flash(:info, gettext("¡Contraseña restablecida!"))
            |> redirect(to: Routes.session_path(conn, :new, conn.assigns.tenant, conn.assigns.locale))
          {:error, %Ecto.Changeset{} = changeset } ->
            render(conn, "edit.html", changeset: changeset, token: token)
        end

      {:error, _} ->
        conn
        |> put_flash(:error, gettext("El enlace no es correcto o ha caducado. El tiempo de validez es de 2 horas."))
        |> render("new.html")
    end
  end

  defp token_salt do
    "OGP-Euskadi"
  end

  defp generate_token(conn, user) do
    Phoenix.Token.sign(conn, token_salt(), user.id)
  end

  defp authenticate_by_token(conn, token, prefix) do
    case Phoenix.Token.verify(conn, token_salt(), token, max_age: 7200) do
      {:ok, user_id} ->
        {:ok, Accounts.get_user!(user_id, prefix)}

      {:error, message} ->
        {:error, message}
    end
  end
end
