defmodule OgpEuskadiWeb.Endpoint do
  use Phoenix.Endpoint, otp_app: :ogp_euskadi

  @session_options [
    store: :cookie,
    key: "_ogp_euskadi_key",
    signing_salt: "9Yjbu3sD"
  ]

  socket "/socket", OgpEuskadiWeb.UserSocket,
    websocket: true,
    longpoll: false

  # LiveView socket
  socket "/live", Phoenix.LiveView.Socket,
    websocket: [connect_info: [session: @session_options]]

  # Enable concurrent testing (https://github.com/elixir-wallaby/wallaby)
  if Application.get_env(:ogp_euskadi, :sql_sandbox) do
    plug Phoenix.Ecto.SQL.Sandbox
  end


  # Serve at "/" the static files from "priv/static" directory.
  #
  # You should set gzip to true if you are running phx.digest
  # when deploying your static files in production.
  plug Plug.Static,
    at: "/",
    from: :ogp_euskadi,
    gzip: false,
    only: ~w(css fonts images js icons admin_icons ods_icons favicon.ico robots.txt manifest.json)

  # Uploaded files are served directly from uploads dir
  plug Plug.Static,
    at: "/uploads",
    from: Path.expand("./uploads"),
    gzip: false

  # Documentation files are served from priv/static/doc dir
  plug Plug.Static,
    at: "/apidoc",
    from: Path.expand("./apidoc"),
    gzip: false


  # Code reloading can be explicitly enabled under the
  # :code_reloader configuration of your endpoint.
  if code_reloading? do
    socket "/phoenix/live_reload/socket", Phoenix.LiveReloader.Socket
    plug Phoenix.LiveReloader
    plug Phoenix.CodeReloader
  end

  # Enable Live dashboard RequestLogger
  plug Phoenix.LiveDashboard.RequestLogger,
    param_key: "request_logger",
    cookie_key: "request_logger"

  plug Plug.RequestId
  plug Plug.Logger

  # Documentation on file uploads:
  # https://www.phoenixframework.org/blog/file-uploads
  plug Plug.Parsers,
    parsers: [:urlencoded, :multipart, :json],
    pass: ["*/*"],
    json_decoder: Phoenix.json_library(),
    length: 10_000_000

  plug Plug.MethodOverride
  plug Plug.Head

  # The session will be stored in the cookie and signed,
  # this means its contents can be read but not tampered with.
  # Set :encryption_salt if you would also like to encrypt it.
  plug Plug.Session, @session_options

  plug OgpEuskadiWeb.Router
end
