defmodule OgpEuskadi.Plugs.PublishedTenantAuth do
  @moduledoc """
  Plug for basic authentication for un published tenants pages.
  If the tenant is not published HTTP login in required using the configuration provided given as use_config parameter.
  This module uses Plug.BasicAuth for the authentication (https://hexdocs.pm/plug/Plug.BasicAuth.html#content).
  """

  import Plug.Conn

  alias OgpEuskadi.Site

  def init(_options) do
    Application.get_env(:ogp_euskadi, :basic_auth)
  end

  def call(conn, config_options) do
    authorize_tenant_site_access(conn, config_options)
  end

  defp authorize_tenant_site_access(conn, config_options) do
    if Site.tenant_is_published(conn.assigns[:tenant]) do
      conn
    else
      with {user, pass} <- Plug.BasicAuth.parse_basic_auth(conn),
           {:ok} <- check_http_login(user, pass, config_options) do
        conn
      else
        _ -> conn |> Plug.BasicAuth.request_basic_auth(realm: config_options[:realm]) |> halt()
      end
    end
  end

  def check_http_login(user, pass, config_options) do
    if Plug.Crypto.secure_compare(user, config_options[:username]) && Plug.Crypto.secure_compare(pass, config_options[:password]) do
      {:ok}
    else
      {:error}
    end
  end
end
