defmodule OgpEuskadi.EntityLogo do
  use Arc.Definition
  use Arc.Ecto.Definition

  import OgpEuskadi.Uploaders.Tools

  @extension_whitelist ~w(.jpg .jpeg .gif .png)

  # To add a thumbnail version:
  @versions [:original, :thumb]

  # Whitelist file extensions:
  def validate({file, _}) do
    @extension_whitelist |> Enum.member?(String.downcase(Path.extname(file.file_name)))
  end

  # Define a thumbnail transformation.
  # NOTE: do not use extent as this option changes the background color
  def transform(:thumb, _) do
    {:convert, "-strip -thumbnail 40x40^ -gravity center -format png", :png}
  end

  def filename(version, {file, _scope}) do
    "logo-#{version}"
  end

  # Override the storage directory:
  def storage_dir(version, {file, scope}) do
    prefix = Ecto.get_meta(scope, :prefix)

    "uploads/#{prefix}/config/"
  end

  # Provide a default URL if there hasn't been a file uploaded
  def default_url(version, scope) do
    "/images/logo-obaba-#{version}.png"
  end

end
