defmodule OgpEuskadi.Photo do
  use Arc.Definition
  use Arc.Ecto.Definition

  import OgpEuskadi.Uploaders.Tools

  @extension_whitelist ~w(.jpg .jpeg .gif .png)

  # Include ecto support (requires package arc_ecto installed):
  # use Arc.Ecto.Definition

  # To add a thumbnail version:
  @versions [:original, :thumb, :carousel]

  # Override the bucket on a per definition basis:
  # def bucket do
  #   :custom_bucket_name
  # end

  # Whitelist file extensions:
  def validate({file, _}) do
    @extension_whitelist |> Enum.member?(String.downcase(Path.extname(file.file_name)))
  end

  # Define a thumbnail transformation:
  def transform(:thumb, _) do
    {:convert, "-strip -thumbnail 250x250^ -gravity center -extent 250x250 -format png", :png}
  end

  # Define a carousel transformation: max width=800px, max height=536.
  # the image is expanded or contracted to fit the specified width and height value while maintaining the aspect ratio.
  # > is used to shrink an image only if its dimension(s) are larger than the corresponding width and/or height arguments
  # https://imagemagick.org/script/command-line-processing.php#geometry
  def transform(:carousel, _) do
    {:convert, "-strip -resize 800x536> -format png", :png}
  end

  def filename(version, {file, _scope}) do
    file_name = Path.basename(file.file_name, Path.extname(file.file_name)) |> sanitize_filename
    "#{file_name}-#{version}"
  end

  # Override the storage directory:
  def storage_dir(version, {file, scope}) do
    prefix = Ecto.get_meta(scope, :prefix)

    "uploads/#{prefix}/activity/#{scope.activity_id}/photos/"
  end

  # Provide a default URL if there hasn't been a file uploaded
  # def default_url(version, scope) do
  #   "/images/avatars/default_#{version}.png"
  # end

  # Specify custom headers for s3 objects
  # Available options are [:cache_control, :content_disposition,
  #    :content_encoding, :content_length, :content_type,
  #    :expect, :expires, :storage_class, :website_redirect_location]
  #
  # def s3_object_headers(version, {file, scope}) do
  #   [content_type: MIME.from_path(file.file_name)]
  # end
end
