# Helpers for action links: edit, delete, new ...

defmodule OgpEuskadiWeb.ActionLinkHelpers do
  use Phoenix.HTML

  import OgpEuskadiWeb.Gettext

  def public_page_link(url, opts \\ %{}) do
    text = opts[:text] || gettext("ver en la parte pública")
    link text, to: url, class: "btn btn-outline-success"
  end

  def delete_link(url, opts \\ %{}) do
    title = opts[:title] || gettext("Eliminar")
    text = opts[:text] || ""
    confirm_message = opts[:confirm_message] || gettext("¿Está seguro?")

    link to: url, method: :delete, title: title, class: "text-danger", data: [confirm: confirm_message] do
      [content_tag(:i, "", class: "fas fa-fw fa-minus-circle"), content_tag(:span, text)]
    end
  end

  def edit_link(url, opts \\ %{}) do
    text = opts[:text] || gettext("modificar")
    title = opts[:title] || text

    link to: url, title: title, class: "btn btn-link" do
      [content_tag(:i, "", class: "fas fa-pen"), content_tag(:span, text)]
    end
  end

  def add_item_link(url, opts \\ %{}) do
    text = opts[:text] || gettext("Añadir")
    title = opts[:title] || text

    link to: url, title: title, class: "btn btn-link btn-lg" do
      [content_tag(:i, "", class: "fas fa-plus"), content_tag(:span, text, class: "small ml-1 link-title")]
    end
  end

  def sort_items_link(url, opts \\ %{}) do
    title = opts[:title] || gettext("Ordenar")

    link to: url, title: title, class: "btn btn-link btn-lg" do
      [content_tag(:i, "", class: "fas fa-sort"), content_tag(:span, title, class: "small ml-1 link-title")]
    end
  end


  def upload_link(url, opts \\ %{}) do
    title = opts[:title] || gettext("Añadir")

    link to: url, title: title, class: "btn btn-link btn-lg" do
      [content_tag(:i, "", class: "fas fa-upload"), content_tag(:span, title, class: "small ml-1 link-title")]
    end
  end

  def download_link(url, opts \\ %{}) do
    title = opts[:title] || gettext("Descargar")
    text = opts[:text] || ""

    link to: url, title: title, class: "btn btn-link" do
      [content_tag(:i, "", class: "fas fa-file-download"), content_tag(:span, text)]
    end
  end

  def expand_link(url, opts \\ %{}) do
    title = opts[:title] || gettext("Información completa")

    link to: url, title: title, class: "btn btn-link btn-lg" do
      [content_tag(:i, "", class: "fas fa-expand"), content_tag(:span, title, class: "small ml-1 link-title")]
    end
  end

  def icon_link_with_text(url, opts \\ %{}) do
    if opts[:counter] do
      link to: url, class: "btn btn-link" do
      [raw(opts[:icon]), content_tag(:span, opts[:text]), content_tag(:span, opts[:counter], class: "badge badge-secondary ml-1")]
      end
    else
      link to: url, class: "ef-btn-link" do
        [raw(opts[:icon]), content_tag(:span, opts[:text])]
      end
    end
  end

  def icon_link_with_text_and_counter_col(url, opts \\ %{}) do
    link_col = content_tag(:div, class: "col") do
      link to: url, class: "ef-btn-link" do
        [raw(opts[:icon]), content_tag(:span, opts[:text])]
      end
    end

    counter_col = content_tag(:div, class: "col-auto") do
      content_tag(:span, opts[:counter], class: "badge badge-secondary ml-1") 
    end

    [link_col, counter_col]
  end


  def add_new_button(url, opts \\ %{}) do
    text = opts[:text] || gettext("Nuevo")

    link text, to: url, class: "d-none d-sm-inline-block btn btn-sm btn-primary shadow-sm"
  end

  def delete_button(url, opts \\ %{}) do
    text = opts[:text] || gettext("Eliminar")
    title = opts[:title]
    confirm_message = opts[:confirm_message] || gettext("¿Está seguro?")

    link to: url, title: title, method: :delete, data: [confirm: confirm_message], class: "btn btn-danger ml-2" do
      content_tag(:span, text, class: "text")
    end
  end

  def discard_button(url, opts \\ %{}) do
    text = opts[:text] || gettext("Desestimar")

    link to: url, title: opts[:title], class: "btn btn-outline-danger ml-2" do
      [OgpEuskadiWeb.LayoutView.discarded_icon(), content_tag(:span, text, class: "text ml-2")]
    end
  end

  def back_button(url, opts \\ %{}) do
    text = opts[:text] || gettext("Volver")

    link to: url, class: "btn btn-secondary ml-2" do
      content_tag(:span, text, class: "text")
    end
  end

  def sort_button(url, opts \\ %{}) do
    text = opts[:text] || gettext("Nuevo")

    link to: url, class: "d-none d-sm-inline-block btn btn-sm btn-secondary shadow-sm ml-2" do
      [content_tag(:i, "", class: "fas fa-sort"), content_tag(:span, text, class: "ml-2")]
    end
  end
end
