defmodule OgpEuskadiWeb.Admin.ActivityView do
  use OgpEuskadiWeb, :view

  # Converts acts list ordered by goal position into Keword list
  # suitable for grouped select options
  def acts_options_for_select(acts) do
    acts
    |> Enum.reduce([], fn a, acc ->
        opt_data = [
              key: a.title,
              value: a.id,
              "data-indicators": Jason.encode!(Enum.map(a.indicators, fn ai ->
                %{id: ai.id, kind_id: ai.kind_id, title: ai.title, units: ai.units, current_value: ai.current_value, goal_value: ai.goal_value}
              end))
            ]
        Keyword.update(
          acc,
          String.to_atom(a.goal.title),
          [opt_data],
          fn current_value -> [opt_data | current_value] end)
      end)
    |> Enum.map(fn {goal_title, goal_acts} -> {goal_title, Enum.reverse(goal_acts)} end)
  end

  def indicator_kinds_data(indicator_kinds) do
    indicator_kinds
    |> Enum.map(fn ik ->
      %{id: ik.id, type: ik.type, icon: OgpEuskadiWeb.IndicatorView.indicator_icon_name(ik.type), name: ik.name, options: OgpEuskadiWeb.IndicatorView.indicator_phases_options(ik.options)}
    end)
    |> Jason.encode!()
  end

  def current_activity_indicators_data(%Ecto.Changeset{}=changeset) do
    changeset
    |> Ecto.Changeset.fetch_field!(:activity_indicators)
    |> Enum.map(fn ai ->
      %{id: ai.id, indicator_id: ai.indicator_id, indicator_value: ai.indicator_value}
    end)
    |> Jason.encode!()
  end

  def current_activity_indicators_data(_) do
    []
    |> Jason.encode!()
  end
end
