defmodule OgpEuskadiWeb.Api.ActView do
  use OgpEuskadiWeb, :view

  alias OgpEuskadi.DateInput

  # Use json_map if it is necessary to  keep map keys order.
  # Otherwise the keys are ordered in aphabetical order.
  # require Jason.Helpers

  def render("index.json", %{acts: acts}) do 
    %{acts: Enum.map(acts, &act_json/1)}
  end

  def render("show.json", %{act: act}) do
    %{act: act_json(act)}
  end


  def act_json(act) do
    %{
      id: act.id,
      goal: %{
        id: act.goal.id,
        title_es: act.goal.title_es,
        title_eu: act.goal.title_eu
      },
      title_es: act.title_es,
      title_eu: act.title_eu,
      description_es: act.description_es,
      description_eu: act.description_eu,
      starts_on: DateInput.date_input_format(act.starts_on),
      starts_on_expected: DateInput.date_input_format(act.starts_on_expected),
      ends_on: DateInput.date_input_format(act.ends_on),
      ends_on_expected: DateInput.date_input_format(act.ends_on_expected),
      draft: act.draft,
      discarded: act.discarded,
      position: act.position,
      topics: Enum.map(act.topics, fn t -> %{id: t.id, title_es: t.title_es, title_eu: t.title_eu} end),
      subdivisions: Enum.map(act.subdivisions, fn s -> %{id: s.id, name_es: s.name_es, name_eu: s.name_eu} end),
      ods: Enum.map(act.ods, fn o -> %{id: o.id, title_es: o.title_es, title_eu: o.title_eu} end),
      indicators: Enum.map(act.indicators, fn act_ind ->
        ind = OgpEuskadi.JsonAPI.set_indicator_api_values(act_ind)
        %{
          id: ind.id,
          title_es: ind.title_es,
          title_eu: ind.title_eu,
          type: ind.indicator_kind.type,
          goal_value: ind.goal_value,
          current_value_es: ind.current_value_es,
          current_value_eu: ind.current_value_eu,
          units_es: ind.units_es,
          units_eu: ind.units_eu,
          inserted_at: ind.inserted_at,
          updated_at: ind.updated_at
        }
      end),
      inserted_at: act.inserted_at,
      updated_at: act.updated_at
    }
  end

end
