defmodule OgpEuskadiWeb.Api.ActivityView do
  use OgpEuskadiWeb, :view

  alias OgpEuskadi.DateInput
  alias OgpEuskadi.JsonAPI

  def render("index.json", %{activities: activities}) do
    %{activities: Enum.map(activities, &activity_json/1)}
  end

  def render("show.json", %{activity: activity}) do
    %{activity: activity_json(activity)}
  end

  def activity_json(activity) do
    %{
      id: activity.id,
      act: %{
        id: activity.act_id,
        title_es: activity.act.title_es,
        title_eu: activity.act.title_eu,
      },
      title_es: activity.title_es,
      title_eu: activity.title_eu,
      description_es: activity.description_es,
      description_eu: activity.description_eu,
      date: DateInput.date_input_format(activity.date),
      activity_indicators: activity.activity_indicators |> Enum.map(fn ai ->
        %{value_es: value_es, value_eu: value_eu, units_es: units_es, units_eu: units_eu} = JsonAPI.indicator_value_and_units(ai.indicator_value, ai.indicator.indicator_kind.type, %{units_es: ai.indicator.units_es, units_eu: ai.indicator.units_eu, indicator_kind: ai.indicator.indicator_kind})

        %{
          indicator: %{
            id: ai.indicator_id,
            title_es: ai.indicator.title_es,
            title_eu: ai.indicator.title_eu,
            units_es: units_es,
            units_eu: units_eu
          },
          indicator_value_es: value_es,
          indicator_value_eu: value_eu,
        }
      end),
      draft: activity.draft,
      inserted_at: activity.inserted_at,
      updated_at: activity.updated_at
    }
  end
end
