defmodule OgpEuskadiWeb.DataHelpers do
  use Phoenix.HTML

  @doc """
    Generates a dt and dd with the item attribute title and value.

    If value_present is false, empty string is returned.
  """
  def show_item_attribute(value_present, title, do: content) do
    show_item_attribute(value_present, title, content)
  end

  def show_item_attribute(value_present, title, content) do
    if value_present do
      [
        content_tag(:dt, title, class: "col-sm-4"),
        content_tag(:dd, content, class: "col-sm-8")
      ]
    else
      ""
    end
  end

  # See https://elixircasts.io/formatting-numbers
  def show_qntty(nil) do
    nil
  end

  def show_qntty(qntty, units \\ "") do
    cond do
      is_integer(qntty) ->
        Number.Delimit.number_to_delimited(qntty, delimiter: ".", precision: 0) <> " " <> units
      is_float(qntty) ->
        Number.Delimit.number_to_delimited(qntty, delimiter: ".", separator: ",", precision: 2) <> " " <> units
      true -> ""
    end
  end

  def show_value_or_empty(value) do
    if !!value do
      value
    else
      "-"
    end
  end

  def show_localized_date(date_value, locale) when is_binary(date_value) do
    case locale do
      "eu" ->
        date_value
        |> String.split("/")
        |> get_localized_date_text("eu")

      _ -> date_value
    end
  end

  def show_localized_date(date_value, locale) when is_nil(date_value) do
    date_value
  end

  def show_localized_date(date_value, locale) do
    get_localized_date_text([
      String.pad_leading(Integer.to_string(date_value.day), 2, "0"),
      String.pad_leading(Integer.to_string(date_value.month), 2, "0"),
      date_value.year
    ], locale)
  end

  def get_localized_date_text([d,m,y], locale) do
    case locale do
      "eu" -> [y,m,d] |> Enum.join("/")
      _ -> [d,m,y] |> Enum.join("/")
    end
  end

end
