defmodule OgpEuskadiWeb.ErrorView do
  use OgpEuskadiWeb, :view

  # If there is a template with the error code in templates/error directory,
  # this template will be loaded.
  # Otherwiswe, the template_not_fund view will be executed.
  # To customize error pages, create the corresponind template in template/errors.

  # If you want to customize a particular status code
  # for a certain format, you may uncomment below.
  # def render("500.html", _assigns) do
  #   "Internal Server Error"
  # end

  # By default, Phoenix returns the status message from
  # the template name. For example, "404.html" becomes
  # "Not Found".
  def template_not_found(template, _assigns) do
    Phoenix.Controller.status_message_from_template(template)
  end

  def get_error_page_data(conn) do
    if conn.assigns[:entity_config] do
      %{
        title: "#{OgpEuskadiWeb.LayoutView.entity_name(conn)}: Error",
        stylesheet: Routes.static_path(conn, "/css/theme-#{OgpEuskadiWeb.LayoutView.color_theme(conn)}.css"),
        tenant: conn.assigns.tenant
       }
    else
      %{
        title: "OGP Euskadi: Error",
        stylesheet: Routes.static_path(conn, "/css/app.css"),
        tenant: nil
      }
    end
  end

  def render("400.json", assigns) do
    case assigns.reason do
      %Ecto.Query.CastError{} = error ->
        %{
          message: "Wrong parameters",
          errors: [%{message: "Value is not correct", name: error.type, value: error.value}]
        }

      %OgpEuskadiWeb.Exceptions.MissingParametersError{} = error ->
        %{
          message: error.message,
          errors: error.detail
        }

      _ -> %{message: "Bad request (#{inspect assigns.reason})"}
    end
  end

  def render("403.json", assigns) do
    case assigns.reason do
      %OgpEuskadiWeb.Exceptions.ForbiddenActionError{} = error ->
         %{
           message: error.message,
           errors: error.detail
         }

      _ -> %{message: inspect assigns.reason}
    end
  end

  def render("422.json", assigns) do
    case assigns.reason do
      %OgpEuskadiWeb.Exceptions.InvalidDataError{} = error ->
         %{
           message: error.message,
           errors: error.detail
         }

      _ -> %{message: inspect assigns.reason}
    end
  end

  def render("404.json", _assigns) do
    %{message: "Record not found. Please, check the ID."}
  end

  def render("500.json", _assigns) do
    %{message: "Something went wrong. We are looking to see what happened."}
  end

end
