defmodule OgpEuskadiWeb.IndicatorView do
  use OgpEuskadiWeb, :view

  alias OgpEuskadi.Basic

  def indicator_icon_name(indicator_kind) do
    case indicator_kind do
      "phases" -> "traffic-light"
      "percentage" -> "percentage"
      _ -> "chart-line"
    end
  end

  def indicator_icon(indicator_kind) do
    content_tag :i, "", class: "fas fa-#{indicator_icon_name(indicator_kind)} fa-2x text-gray-300 ef-indicator-icon ef-#{indicator_kind}-icon"
  end

  def indicator_color(indicator_kind) do
    case indicator_kind do
      "phases" -> "success"
      "percentage" -> "info"
      _ -> "warning"
    end
  end

  def indicator_kind_name(indicator_kind) do
    case indicator_kind do
      "phases" -> "Por fases"
      "percentage" -> "Porcentaje"
      _ -> "Numérico"
    end
  end

  def indicator_phases_options(options_text) when is_binary(options_text) do
    String.split(options_text, "|")
  end

  def indicator_phases_options(options_text) do
    ""
  end

  def indicator_vis("percentage" = type, indicator, locale) do
    r = 70
    stroke_width = 1
    stroke_color = "#ddd"
    fill_color = "#eee"
    width = 200 + stroke_width
    height = r + 4
    offset = stroke_width/2
    cx = offset + r
    cy = offset + r
    percentage =
      if !!indicator.current_value do
        Decimal.to_float(indicator.current_value)
      else
        0
      end
    alpha = :math.pi() - percentage/100 * :math.pi()
    x = cx + :math.cos(alpha)*r
    y = cy - :math.sin(alpha)*r

    chart = content_tag(:svg, width: width, height: height) do
      semicircle = "
        <path d=\"M #{offset}  #{cy}
                 A #{r}  #{r}  0 0 1 #{cx + r}  #{cy}
                 L #{cx } #{cy}
                \" class=\"percentage_block pending\" stroke=\"#{stroke_color}\" fill=\"#{fill_color}\" stroke-width=\"#{stroke_width}\" fill-opacity=\"0.5\"/>"
      arc ="
        <path d=\"M #{offset}  #{cy}
                 A #{r} #{r}  0 0 1 #{x} #{y}
                 L #{cx} #{cy}  L #{offset - stroke_width/2}  #{cy}
                \" class=\"percentage_block filled\" stroke=\"#{stroke_color}\" fill=\"#0ff\" stroke-width=\"#{stroke_width}\" fill-opacity=\"1\"/>"

      [raw(semicircle), raw(arc)]
    end

    value = content_tag(:span, indicator_current_value(type, indicator, locale), class: "text-lg indicator-value")
    text =
      content_tag(:p, class: "precentage_current_value") do
        value
      end

    [chart, text]
  end

  def indicator_vis("phases" = type, indicator, _locale) do
    max_phase = indicator_phases_options(indicator.indicator_kind.options_es) |> length()

    a =
      if max_phase < 5 do
        60
      else
        50
      end

    stroke_width = 1
    width = max_phase*a + 3*stroke_width
    height = a + stroke_width
    offset = stroke_width/2

    current_phase =
      if !!indicator.current_value do
        Decimal.to_integer(indicator.current_value)
      else
        0
      end

    chart = content_tag(:svg, width: width, height: height) do
      Enum.to_list(0..(max_phase-1))
      |> Enum.map(fn phase ->
        phase_offset = offset + phase*a
        raw("<path d=\"M #{phase_offset} #{offset} H #{phase_offset + a} V #{offset + a} H #{phase_offset} Z\" class=\"phase_block #{indicator_phase_status(phase, current_phase)}\" stroke-width=\"#{stroke_width}\"/>")
      end)
    end

    value = content_tag(:span, indicator_current_value(type, indicator, nil), class: "indicator-value")
    text =
      content_tag(:p, class: "phase_current_value") do
        value
      end

    [chart, text]
  end

  def indicator_vis("numeric" = type, indicator, _locale) do
    label = content_tag(:span, indicator_value_label(type)<>":", class: "label mr-2 indicator-value-label")
    value = content_tag(:span, indicator_current_value(type, indicator, nil), class: "text-lg indicator-value")
    value_text =
      content_tag(:p, class: "numeric_current_value") do
        [label, value]
      end

    if !!indicator.goal_value do
      goal_label = content_tag(:span, gettext("Objetivo")<>":", class: "label mr-2 indicator-value-label")
      goal_value_text = content_tag(:span, indicator_goal_value(type, indicator, nil), class: "text-lg indicator-value nobr")
      goal_text =
        content_tag(:p, class: "numeric_goal_value") do
          [goal_label, goal_value_text]
        end
      [value_text, goal_text]
    else
     [value_text]
    end

  end

  def indicator_phase_status(phase, current_phase) do
    cond do
      phase < current_phase -> "filled"
      phase == current_phase -> "filled"
      true -> "pending"
    end
  end

  def indicator_value_label("numeric") do
    gettext("Valor actual")
  end

  def indicator_value_label("percentage") do
    gettext("Valor actual")
  end

  def indicator_value_label("phases") do
    gettext("Fase actual")
  end

  def indicator_formatted_value("percentage", value, units, _phases_options, locale) do
    v = if !!value do
      percentage_v = pretty_number(value)
      percentage_v = if (locale == "eu") do
        "%"<>percentage_v
      else
        percentage_v<>"%"
      end
    else
      0
    end

    "#{v} #{units}"
  end

  def indicator_formatted_value("numeric", value, units, _phases_options, _locale) do
    v = if !!value do
      pretty_number(value)
    else
      ""
    end

    raw("#{v}&nbsp;#{units}")
  end

  def indicator_formatted_value("phases", value, units, phases_options, _locale) do
    phase_number = if !!value do
      Decimal.to_integer(value)
    else
      0
    end

    case indicator_phases_options(phases_options) |> Enum.at(phase_number) do
      text -> text
      nil -> ""
    end
  end

  def indicator_current_value("numeric" = type, indicator, _locale) do
    indicator_formatted_value(type, indicator.current_value, indicator.units, nil, nil)
  end

  def indicator_current_value("percentage" = type, indicator, locale) do
    indicator_formatted_value(type, indicator.current_value, indicator.units, nil, locale)
  end

  def indicator_current_value("phases", indicator, _locale) do
    phases_options = indicator.indicator_kind.options
    indicator_formatted_value("phases", indicator.current_value, indicator.units, phases_options, nil)
  end

  def indicator_goal_value("numeric" = type, indicator, _locale) do
    indicator_formatted_value(type, indicator.goal_value, indicator.units, nil, nil)
  end

  defp pretty_number(value) do
    if Decimal.equal?(Decimal.to_integer(Decimal.round(value)), value) do
      Number.Delimit.number_to_delimited(value, delimiter: ".", precision: 0)
    else
      Number.Delimit.number_to_delimited(value, delimiter: ".", separator: ",", precision: 2)
    end
  end
end
