defmodule OgpEuskadiWeb.LayoutView do
  use OgpEuskadiWeb, :view

  def entity_name(conn) do
    if conn.assigns[:entity_config] do
      conn.assigns.entity_config.name
    else
      "Obaba"
    end
  end

  def entity_logo_url(conn) do
    if conn.assigns[:entity_config] do
      OgpEuskadi.EntityLogo.url({conn.assigns.entity_config.logo, conn.assigns.entity_config}, :thumb)
    else
      OgpEuskadi.EntityLogo.url(%OgpEuskadi.Config.EntityConfig{}.logo, :thumb) # default logo
    end
  end

  def entity_services(conn) do
    conn.assigns[:entity_services] || []
  end

  def entity_footer_text(conn) do
    if conn.assigns[:entity_config] do
      conn.assigns.entity_config.footer_text || ""
    else
      ""
    end
  end

  def color_theme(conn) do
    if conn.assigns[:entity_config] do
      conn.assigns.entity_config.color_theme || "blue"
    else
      "blue"
    end
  end

  def page_title do
    "OGP Euskadi"
  end

  def ogp_euskadi_project_url(locale) do
    if (locale == "eu") do
      "https://www.ogp.euskadi.eus/ogp-konpromisoak/-/kontuak-ematea-agintaldiko-planen-bidez/#3255"
    else
      "https://www.ogp.euskadi.eus/ogp-compromisos/-/rendicion-de-cuentas-a-traves-de-planes-de-mandato/#3255"
    end
  end

  def sidebar_title(conn) do
    entity_name(conn)
  end

  def dashboard_title do
    gettext("Plan de mandato")
  end

  def change_locale_link(conn, locale) do
    link_class = if (locale == String.to_atom(conn.assigns.locale)), do: "active", else: "passive"
    link locale, to: String.replace(conn.request_path, ~r/\/(es|eu)(\/*)/, "/#{locale}\\2"), class: "#{link_class}"
  end

  def nav_link_class(controller_name, conn) do
    current = case conn.status do
      404 ->
        nil
      _ ->
        String.split(Atom.to_string(Phoenix.Controller.controller_module(conn)), ".") |> List.last |> String.downcase
    end

    if (current == "#{controller_name}controller") do
      "active"
    else
      "passive"
    end
  end

  def goal_icon() do
    content_tag :i, "", class: "fas fa-fw fa-bullseye"
  end

  def act_icon() do
    content_tag :i, "", class: "fas fa-fw fa-clipboard-list"
  end

  def activity_icon() do
    content_tag :i, "", class: "fas fa-fw fa-tasks"
  end

  def topic_icon() do
    content_tag :i, "", class: "fas fa-fw fa-tags"
  end

  def subdivision_icon() do
    content_tag :i, "", class: "fas fa-fw fa-map"
  end

  def ods_icon() do
    content_tag :i, "", class: "far fa-fw fa-circle"
  end

  def draft_icon() do
    content_tag :i, "", class: "far fa-eye-slash alert-warning"
  end

  def discarded_icon() do
    content_tag :i, "", class: "fas fa-ban"
  end

  def info_icon() do
    content_tag :i, "", class: "fas fa-info-circle"
  end

  def entity_services_icon() do
    content_tag :i, "", class: "fas fa-hands-helping"
  end

  def danger_icon() do
    content_tag :i, "", class: "fas fa-exclamation-triangle"
  end

  def help_message_block(text: text, button: button_opts) do
    content = [content_tag(:span, content_tag(:i, "", class: "fas fa-info-circle"), class: "mr-2"), raw(text)]

    content = if map_size(button_opts) > 0 do
      [content | content_tag(:div, link(button_opts[:text], to: button_opts[:url], class: "d-none d-sm-inline-block btn btn-sm btn-info"), class: "ef-actions text-center mt-4")]
    else
      content
    end


    content_tag :div, class: "help-message" do
      content
    end
  end

  def danger_message_block(text: text) do
    content = [content_tag(:span, danger_icon(), class: "mr-2"), raw(text)]

    content_tag :div, class: "danger-message" do
      content
    end
  end
end
