# Documentation on triggers in PostgreSQL 9.2 https://www.postgresql.org/docs/9.2/plpgsql-trigger.html
# The function set_initial_position is defined in the public scheme
# (see priv/repo/migrations/20200306100544_create_next_position_functions_and_triggers.exs)
defmodule OgpEuskadi.Repo.Migrations.AddGoalPosition do
  use Ecto.Migration

  def up do
    alter table(:goals) do
      add :position, :integer, default: 0
    end

    execute("CREATE TRIGGER set_initial_goal_position BEFORE INSERT ON #{prefix()}.goals FOR EACH ROW EXECUTE PROCEDURE set_initial_position();")
  end

  def down do
    alter table(:goals) do
      remove :position
    end

    execute("DROP TRIGGER set_initial_goal_position ON #{prefix()}.goals;")
  end

end
