defmodule OgpEuskadi.Repo.Migrations.ActsSubdivisionsAndAllSubdivisions do
  use Ecto.Migration

  import Ecto.Query
  alias OgpEuskadi.Repo
  alias OgpEuskadi.Plan
  alias OgpEuskadi.Plan.Act

  def up do
    from(a in Act, where: a.all_subdivisions==^true, preload: [:topics, :subdivisions, :ods])
    |> Repo.all(prefix: prefix())
    |> Enum.map(fn act ->
      IO.puts "Clear subdivisions ids for act #{act.id}, #{act.title_es}"
      topics_ids = Enum.map(act.topics, fn x -> Integer.to_string(x.id) end)
      ods_ids = Enum.map(act.ods, fn x -> Integer.to_string(x.id) end)
      act_params = %{"topics_ids" => topics_ids, "ods_ids" => ods_ids, "subdvisions_ids" => []}
      case Plan.update_act(act, act_params) do
        {:ok, updated_act} ->
          IO.puts "UPDATED act #{act.id}, original topics_ids=#{inspect(topics_ids)}, current topics_ids = #{inspect(Enum.map(updated_act.topics, fn x -> Integer.to_string(x.id) end))}, ods_ids = #{ods_ids}, current_ods_ids = #{inspect(Enum.map(updated_act.ods, fn x -> Integer.to_string(x.id) end))} "
        {:error, %Ecto.Changeset{} = changeset} ->
          IO.puts "ERROR updating act #{act.id}"
          IO.puts inspect(changeset)
      end
    end)
  end

  def down do
    IO.puts "Irreversible"
  end
end
