defmodule OgpEuskadi.BasicTest do
  use OgpEuskadi.DataCase

  alias OgpEuskadi.Basic

  @prefix "ogpe_test_tenant"

  describe "topics" do
    alias OgpEuskadi.Basic.Topic

    @valid_attrs %{title_es: "some title_es", title_eu: "some title_eu"}
    @update_attrs %{title_es: "some updated title_es", title_eu: "some updated title_eu"}
    @invalid_attrs %{title_es: nil, title_eu: nil}

    def topic_fixture(attrs \\ %{}) do
      {:ok, topic} =
        attrs
        |> Enum.into(@valid_attrs)
        |> Basic.create_topic(@prefix)

      Basic.get_topic!(topic.id, @prefix)
    end

    test "list_topics/0 returns all topics" do
      topic = topic_fixture()
      assert Enum.any?(Basic.list_topics(@prefix), fn(t) -> t.id == topic.id end)
    end

    test "get_topic!/1 returns the topic with given id" do
      topic = topic_fixture()
      assert Basic.get_topic!(topic.id, @prefix) == topic
    end

    test "create_topic/1 with valid data creates a topic" do
      assert {:ok, %Topic{} = topic} = Basic.create_topic(@valid_attrs, @prefix)
      assert topic.title_es == "some title_es"
      assert topic.title_eu == "some title_eu"
    end

    test "create_topic/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Basic.create_topic(@invalid_attrs, @prefix)
    end

    test "update_topic/2 with valid data updates the topic" do
      topic = topic_fixture()
      assert {:ok, %Topic{} = topic} = Basic.update_topic(topic, @update_attrs)
      assert topic.title_es == "some updated title_es"
      assert topic.title_eu == "some updated title_eu"
    end

    test "update_topic/2 with invalid data returns error changeset" do
      topic = topic_fixture()
      assert {:error, %Ecto.Changeset{}} = Basic.update_topic(topic, @invalid_attrs)
      assert topic == Basic.get_topic!(topic.id, @prefix)
    end

    test "delete_topic/1 deletes the topic without acts" do
      topic = topic_fixture()
      assert {:ok, %Topic{}} = Basic.delete_topic(topic)
      assert_raise Ecto.NoResultsError, fn -> Basic.get_topic!(topic.id, @prefix) end
    end

    test "change_topic/1 returns a topic changeset" do
      topic = topic_fixture()
      assert %Ecto.Changeset{} = Basic.change_topic(topic)
    end
  end
end
