defmodule OgpEuskadiWeb.Api.OdsControllerTest do
  use OgpEuskadiWeb.ConnCase

  alias OgpEuskadi.Auth
  alias OgpEuskadi.Basic
  alias OgpEuskadiWeb.Api.OdsView

  @prefix "ogpe_test_tenant"

  describe "not authenticaed client" do
    test "return unauthorized", %{conn: conn} do
      conn = get conn, Routes.api_ods_path(conn, :index)

      assert json_response(conn, 401) == %{"error" => "unauthenticated"}
    end
  end

  describe "authenticated client" do
    setup %{conn: conn} do

      api_client = insert(:api_client_with_entity)

      # create the token
      {:ok, token, _claims} = Auth.authenticate_client_by_api_key!(api_client.client, api_client.key)

      # add authorization header to request
      conn = conn |> put_req_header("authorization", "Bearer #{token}")

      %{conn: conn}
    end

    test "#index renders a list of ods", %{conn: conn} do
      conn = get conn, Routes.api_ods_path(conn, :index)

      assert json_response(conn, 200) == render_json(OdsView, "index.json", items: Basic.list_ods(@prefix))
    end

  end

end
