defmodule OgpEuskadiWeb.PasswordResetControllerTest do
  use OgpEuskadiWeb.ConnCase
  use Bamboo.Test, shared: :true

  @username Application.get_env(:ogp_euskadi, :basic_auth)[:username]
  @password Application.get_env(:ogp_euskadi, :basic_auth)[:password]

  defp using_basic_auth(conn, username, password) do
    header_content = "Basic " <> Base.encode64("#{username}:#{password}")
    conn |> put_req_header("authorization", header_content)
  end

  alias OgpEuskadi.Accounts

  def fixture(:user) do
    {:ok, user} = Accounts.create_user(%{username: "Test", credential: %{email: "test@efaber.net", password: "secret"}}, "ogpe_test_tenant")
    Accounts.get_user!(user.id, "ogpe_test_tenant")
  end

  describe "create for exsiting user" do
    setup [:create_user]

    test "create reset token and send email", %{conn: conn, user: user} do
      conn = conn
       |> using_basic_auth(@username, @password)
       |> post(Routes.password_reset_path(conn, :create, "test_tenant", "es"), user: %{"email" => user.credential.email})

      assert html_response(conn, 200) =~ "¡Instrucciones enviadas a #{user.credential.email}!"

      assert_email_delivered_with(subject: "OGP Euskadi: Restablecer contraseña", to: [user.credential.email], text_body: ~r/password_reset/)
    end

    test "edit with token", %{conn: conn, user: user} do
      token = Phoenix.Token.sign(OgpEuskadiWeb.Endpoint, "OGP-Euskadi", user.id)

      conn = conn
       |> using_basic_auth(@username, @password)
       |> get(Routes.password_reset_path(conn, :edit, "test_tenant", "es", token: token))

      assert html_response(conn, 200) =~ "Establecer contraseña"
    end

    test "update user credential", %{conn: conn, user: user} do
      token = Phoenix.Token.sign(OgpEuskadiWeb.Endpoint, "OGP-Euskadi", user.id)

      conn = conn
       |> using_basic_auth(@username, @password)
       |> put(Routes.password_reset_path(conn, :update, "test_tenant", "es"), token: token, credential: %{"password" => "new_secret", "password_confirmation" => "new_secret"})

      # 2DO Check the new password is saved 

      assert redirected_to(conn) =~ "/sessions/new"
    end

  end

  describe "create for not registered email" do
    test "show email send text but does not send email", %{conn: conn} do
      user_email = "test@efaber.net"

      conn = conn
       |> using_basic_auth(@username, @password)
       |> post(Routes.password_reset_path(conn, :create, "test_tenant", "es"), user: %{"email" => user_email})
      assert html_response(conn, 200) =~ "Ya te hemos enviado a tu cuenta de correo las instrucciones para efectuar el cambio de contraseña"

      assert_no_emails_delivered()
    end
  end

  defp create_user(_) do
    user = fixture(:user)
    {:ok, user: user}
  end
end
