defmodule OgpEuskadiWeb.Tenant.Admin.GoalManagementTest do
  use OgpEuskadiWeb.IntegrationCase, async: true

  import Wallaby.Query, only: [css: 2, text_field: 1, button: 1, link: 1]

  alias OgpEuskadi.Accounts
  alias OgpEuskadi.Plan

  @tenant "test_tenant"

  def fixture(:user) do
    {:ok, user} = Accounts.create_user(%{username: "Test", credential: %{email: "test@efaber.net", password: "secret"}}, "ogpe_#{@tenant}")
    Accounts.get_user!(user.id, "ogpe_test_tenant")
  end

  def fixture(:goal) do
    Plan.create_goal(%{title_es: "Objetivo 1", description_es: "Primer objetivo", draft: false}, "ogpe_#{@tenant}")
  end

  describe "create for exsiting user" do
    setup [:create_user]

    test "reorder goals", %{session: session, user: user} do
      login(session, user)

      goal1 = tenant_insert(:goal)
      goal2 = tenant_insert(:goal)

      session
      |> visit("/#{@tenant}/es/admin/goal")
      |> click(link("Ordenar objetivos"))
      |> assert_has(css(".sort-form", count: 1))
      |> click(button("Guardar el nuevo orden"))
      |> assert_has(link("Ordenar objetivos"))
      |> assert_has(css(".page_heading", text: "Objetivos"))
      |> assert_has(css(".alert", count: 1))
    end
  end

  defp create_user(_) do
    user = fixture(:user)
    {:ok, user: user}
  end

  defp login(session, user) do
    session
    |> visit("/#{@tenant}/es/sessions/new")
    |> fill_in(text_field("Email"), with: user.credential.email)
    |> fill_in(text_field("Contraseña"), with: "secret")
    |> click(button("Entrar"))
    |> assert_has(css(".alert", text: "Hola"))
  end
end
