# Based on https://github.com/smeevil/set_locale/blob/master/test/set_locale_test.exs
defmodule OgpEuskadiWeb.Plugs.SetLocaleTest do
  use OgpEuskadiWeb.ConnCase

  import Plug.Conn
  import Phoenix.ConnTest

  alias OgpEuskadiWeb.Plugs.SetLocale

  defmodule MyGettext do
    use Gettext, otp_app: :ogp_euskadi
  end

  @default_locale "en"
  @default_options %SetLocale.Config{gettext: MyGettext, default_locale: @default_locale}

  describe "init" do
    test "it enforces gettext key" do
      assert_raise ArgumentError, fn -> SetLocale.init(default_locale: "en-gb") end
    end

    test "it enforces default_locale key" do
      assert_raise ArgumentError, fn -> SetLocale.init(gettext: MyGettext) end
    end

    test "it works with all options given" do
      assert SetLocale.init(gettext: MyGettext, default_locale: "es") == %SetLocale.Config{gettext: OgpEuskadiWeb.Plugs.SetLocaleTest.MyGettext, default_locale: "es"}
    end
  end

  describe "when no locale is given" do
    test "when a tenant root path is requested, it should redirect to default locale" do
      assert Gettext.get_locale(MyGettext) == "en"
      current_tenant = "ogpe_test_tenant"

      conn =
        Phoenix.ConnTest.build_conn(:get, "/#{current_tenant}")
        |> assign(:tenant, current_tenant)
        |> SetLocale.call(@default_options)

      assert redirected_to(conn) == "/#{current_tenant}/#{@default_locale}/"
    end

    test "when a tenant and locale is present, it should only assign it" do
      assert Gettext.get_locale(MyGettext) == "en"
      current_tenant = "ogpe_test_tenant"

      conn =
        Phoenix.ConnTest.build_conn(:get, "/#{current_tenant}/es", %{locale: "es"})
        |> assign(:tenant, current_tenant)
        |> SetLocale.call(@default_options)

      assert conn.status == nil
      assert conn.assigns.locale == "es"
      assert Gettext.get_locale(MyGettext) == "es"
    end

    test "when a tenant is given but the locale is not locale, but a part of the url it redirects to default locale" do
      current_tenant = "ogpe_test_tenant"
      default_locale = Gettext.get_locale(MyGettext)

      conn =
        Phoenix.ConnTest.build_conn(:get, "/#{current_tenant}/foo/bar")
        |> assign(:tenant, current_tenant)
        |> SetLocale.call(@default_options)

      assert redirected_to(conn) == "/#{current_tenant}/#{default_locale}/foo/bar"
    end
  end
end
