defmodule OgpEuskadiWeb.IntegrationCase do
  @moduledoc """
  This module defines the test case to be used for integration tests with Wallaby.
  """

  use ExUnit.CaseTemplate

  using do
    quote do
      use Wallaby.DSL

      alias OgpEuskadi.Repo
      import Ecto
      import Ecto.Changeset
      import Ecto.Query

      import OgpEuskadiWeb.Router.Helpers

      import OgpEuskadi.Factory

      import Wallaby.Query, only: [css: 2, text_field: 1, button: 1, link: 1]

      defp tenant_login(session, user) do
        session
        |> visit("/test_tenant/es/sessions/new")
        |> fill_in(text_field("Email"), with: user.credential.email)
        |> fill_in(text_field("Contraseña"), with: "secret")
        |> click(button("Entrar"))
        |> assert_has(css(".alert", text: "Hola"))
      end

      # Fills the first ckeditor field and returns the parent session
      defp fill_ckeditor_field_text(session, text) do
        session
        |> find(Wallaby.Query.css(".ck-editor__editable", count: :any))
        |> List.first
        |> send_keys(text)

        session
      end
    end
  end

  setup tags do
    :ok = Ecto.Adapters.SQL.Sandbox.checkout(OgpEuskadi.Repo)

    unless tags[:async] do
      Ecto.Adapters.SQL.Sandbox.mode(OgpEuskadi.Repo, {:shared, self()})
    end

    metadata = Phoenix.Ecto.SQL.Sandbox.metadata_for(OgpEuskadi.Repo, self())
    {:ok, session} = Wallaby.start_session(metadata: metadata)
    {:ok, session: session} # makes the session available to all integration tests
  end
end
